@@ -20,6 +20,7 @@
 
 #include <config.h>
 #include <ctype.h>
+#include <stdlib.h>
 
 #include <glib/gstdio.h>
 #include <gio/gio.h>
@@ -55,7 +56,7 @@
 #define ANJUTA_PIXMAP_BUILD            "anjuta-build"
 #define ANJUTA_STOCK_BUILD             "anjuta-build"
 
-#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-build-basic-autotools-plugin.ui"
+#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-build-basic-autotools-plugin.xml"
 #define MAX_BUILD_PANES 3
 #define PREF_INDICATORS_AUTOMATIC "indicators.automatic"
 #define PREF_INSTALL_ROOT "build.install.root"
@@ -187,10 +188,13 @@ static void on_root_check_toggled(GtkWidget* toggle_button, GtkWidget* entry)
 }
 
 static gboolean
-project_has_configure (BasicAutotoolsPlugin *bb_plugin)
+directory_has_makefile_am (BasicAutotoolsPlugin *bb_plugin, const char *dirname )
 {
 	gchar *configure;
+	gchar *makefile_am;
+	gboolean makefile_am_exists;
 
+	/* We need configure.ac or configure.in too */	
 	if (bb_plugin->project_root_dir == NULL) return FALSE;
 	
 	configure = g_build_filename (bb_plugin->project_root_dir, "configure.ac", NULL);
@@ -207,7 +211,12 @@ project_has_configure (BasicAutotoolsPlugin *bb_plugin)
 	}
 	g_free (configure);
 
-	return TRUE;
+	/* Check for Makefile.am */
+	makefile_am = g_build_filename (dirname, "Makefile.am", NULL);
+	makefile_am_exists = g_file_test (makefile_am, G_FILE_TEST_EXISTS);
+	g_free (makefile_am);
+
+	return makefile_am_exists;
 }
 
 static gboolean
@@ -452,6 +461,7 @@ build_context_destroy_command (BuildContext *context)
 static gboolean
 build_context_destroy_view (BuildContext *context)
 {
+	BasicAutotoolsPlugin* plugin = ANJUTA_PLUGIN_BASIC_AUTOTOOLS (context->plugin);
 	if (context->message_view)
 	{
 		gtk_widget_destroy (GTK_WIDGET (context->message_view));
@@ -473,21 +483,22 @@ build_context_destroy_view (BuildContext *context)
 					 NULL);
 	g_slist_free (context->locations);
 	context->locations = NULL;
-	
+
 	/* Empty context, remove from pool */
 	if (context->launcher == NULL)
-	{
-		ANJUTA_PLUGIN_BASIC_AUTOTOOLS (context->plugin)->contexts_pool =
-			g_list_remove (ANJUTA_PLUGIN_BASIC_AUTOTOOLS (context->plugin)->contexts_pool,
-							context);
+	{	
+		plugin->contexts_pool =
+			g_list_remove (plugin->contexts_pool,
+			               context);
 		g_free (context);
-		
-		return TRUE;
 	}
 	else
 	{
-		return FALSE;
+		/* Kill process */
+		anjuta_launcher_signal (context->launcher, SIGKILL);
 	}
+
+	return TRUE;
 }
 	
 static void
@@ -537,8 +548,7 @@ build_regex_load ()
 		gchar **tokens;
 		BuildPattern *pattern;
 		
-		fgets (buffer, 1024, fp);
-		if (ferror (fp))
+		if (!fgets (buffer, 1024, fp))
 			break;
 		tokens = g_strsplit (buffer, "|||", 3);
 		
@@ -932,7 +942,7 @@ on_build_mesg_format (IAnjutaMessageView *view, const gchar *one_line,
 			context->locations = g_slist_prepend (context->locations, loc);
 			
 			/* If current editor file is same as indicator file, set indicator */
-			if (anjuta_preferences_get_int (anjuta_shell_get_preferences (context->plugin->shell, NULL), PREF_INDICATORS_AUTOMATIC))
+			if (anjuta_preferences_get_bool (anjuta_shell_get_preferences (context->plugin->shell, NULL), PREF_INDICATORS_AUTOMATIC))
 			{
 				build_indicator_location_set (loc, p->current_editor,
 											  p->current_editor_filename);
@@ -1048,19 +1058,28 @@ on_build_terminated (AnjutaLauncher *launcher,
 	/* Message view could have been destroyed before */
 	if (context->message_view)
 	{
+		IAnjutaMessageManager *mesg_manager;
 		gchar *buff1;
 	
 		buff1 = g_strdup_printf (_("Total time taken: %lu secs\n"),
 								 time_taken);
+		mesg_manager = anjuta_shell_get_interface (ANJUTA_PLUGIN (context->plugin)->shell,
+									IAnjutaMessageManager, NULL);
 		if (status)
 		{
 			ianjuta_message_view_buffer_append (context->message_view,
 									_("Completed unsuccessfully\n"), NULL);
+			ianjuta_message_manager_set_view_icon_from_stock (mesg_manager,
+									context->message_view,
+									GTK_STOCK_STOP, NULL);
 		}
 		else
 		{
 			ianjuta_message_view_buffer_append (context->message_view,
 									   _("Completed successfully\n"), NULL);
+			ianjuta_message_manager_set_view_icon_from_stock (mesg_manager,
+									context->message_view,
+									GTK_STOCK_APPLY, NULL);
 		}
 		ianjuta_message_view_buffer_append (context->message_view, buff1, NULL);
 		g_free (buff1);
@@ -1091,6 +1110,45 @@ g_hashtable_foreach_true (gpointer key, gpointer value, gpointer user_data)
 	return TRUE;
 }
 
+static void
+build_set_animation (IAnjutaMessageManager* mesg_manager, BuildContext* context)
+{
+	GtkIconTheme *icon_theme = gtk_icon_theme_get_default ();
+	GtkIconInfo *icon_info;
+	const gchar *name;
+	icon_info = gtk_icon_theme_lookup_icon (icon_theme, "process-working", 16, 0);
+	name = gtk_icon_info_get_filename (icon_info);
+	if (name != NULL)
+	{
+		int size = gtk_icon_info_get_base_size (icon_info);
+		GdkPixbufSimpleAnim* anim = gdk_pixbuf_simple_anim_new (size, size, 5);
+		GdkPixbuf *image = gdk_pixbuf_new_from_file (name, NULL);
+		if (image)
+		{
+			int grid_width = gdk_pixbuf_get_width (image);
+			int grid_height = gdk_pixbuf_get_height (image);
+			int x,y;
+			for (y = 0; y < grid_height; y += size)
+			{
+				for (x = 0; x < grid_width ; x += size)
+				{
+					GdkPixbuf *pixbuf = gdk_pixbuf_new_subpixbuf (image, x, y, size,size);
+					if (pixbuf)
+					{
+						gdk_pixbuf_simple_anim_add_frame (anim, pixbuf);
+					}
+				}
+			}
+			ianjuta_message_manager_set_view_icon (mesg_manager,
+			                                       context->message_view,
+			                                       GDK_PIXBUF_ANIMATION (anim), NULL);
+			g_object_unref (image);
+		}
+	}
+	gtk_icon_info_free (icon_info);
+}
+
+
 static BuildContext*
 build_get_context_with_message(BasicAutotoolsPlugin *plugin, const gchar *dir)
 {
@@ -1141,6 +1199,7 @@ build_get_context_with_message(BasicAutotoolsPlugin *plugin, const gchar *dir)
 	}
 	else
 	{
+		
 		/* If no free context found, create one */
 		context = g_new0 (BuildContext, 1);
 		context->plugin = ANJUTA_PLUGIN(plugin);
@@ -1150,6 +1209,7 @@ build_get_context_with_message(BasicAutotoolsPlugin *plugin, const gchar *dir)
 		context->message_view =
 			ianjuta_message_manager_add_view (mesg_manager, mname,
 											  ICON_FILE, NULL);
+
 		g_signal_connect (G_OBJECT (context->message_view), "buffer_flushed",
 						  G_CALLBACK (on_build_mesg_format), context);
 		g_signal_connect (G_OBJECT (context->message_view), "message_clicked",
@@ -1157,6 +1217,7 @@ build_get_context_with_message(BasicAutotoolsPlugin *plugin, const gchar *dir)
 		g_object_weak_ref (G_OBJECT (context->message_view),
 						   (GWeakNotify)on_message_view_destroyed, context);
 	}
+	build_set_animation (mesg_manager, context);
 
 	ianjuta_message_manager_set_current_view (mesg_manager,
 											  context->message_view, NULL);
@@ -1224,22 +1285,6 @@ build_get_context (BasicAutotoolsPlugin *plugin, const gchar *dir,
 	return context;
 }
 
-/* Save all current anjuta files */
-static void
-save_all_files (AnjutaPlugin *plugin)
-{
-	IAnjutaDocumentManager *docman;
-	IAnjutaFileSavable* save;
-
-	docman = anjuta_shell_get_interface (plugin->shell, IAnjutaDocumentManager, NULL);
-	/* No document manager, so no file to save */
-	if (docman != NULL)
-	{
-		save = IANJUTA_FILE_SAVABLE (docman);
-		if (save) ianjuta_file_savable_save (save, NULL);
-	}
-}
-
 static void
 build_set_command_in_context (BuildContext* context, BuildProgram *prog)
 {
@@ -1257,17 +1302,17 @@ build_execute_command_in_context (BuildContext* context, GError **err)
 	/* Send options to make */
 	if (strcmp (build_program_get_basename (context->program), "make") == 0)
 	{
-		if (!anjuta_preferences_get_int (prefs , PREF_TRANSLATE_MESSAGE))
+		if (!anjuta_preferences_get_bool (prefs , PREF_TRANSLATE_MESSAGE))
 		{
 			build_program_add_env (context->program, "LANGUAGE", "C");
 		}
-		if (anjuta_preferences_get_int (prefs , PREF_PARALLEL_MAKE))
+		if (anjuta_preferences_get_bool (prefs , PREF_PARALLEL_MAKE))
 		{
 			gchar *arg = g_strdup_printf ("-j%d", anjuta_preferences_get_int (prefs , PREF_PARALLEL_MAKE_JOB));
 			build_program_insert_arg (context->program, 1, arg);
 			g_free (arg);
 		}
-		if (anjuta_preferences_get_int (prefs , PREF_CONTINUE_ON_ERROR))
+		if (anjuta_preferences_get_bool (prefs , PREF_CONTINUE_ON_ERROR))
 		{
 			build_program_insert_arg (context->program, 1, "-k");
 		}
@@ -1505,7 +1550,7 @@ get_root_install_command(BasicAutotoolsPlugin *bplugin)
 {
 	AnjutaPlugin* plugin = ANJUTA_PLUGIN(bplugin);
 	AnjutaPreferences* prefs = anjuta_shell_get_preferences (plugin->shell, NULL);
-	if (anjuta_preferences_get_int (prefs , PREF_INSTALL_ROOT))
+	if (anjuta_preferences_get_bool (prefs , PREF_INSTALL_ROOT))
 	{
 		gchar* command = anjuta_preferences_get(prefs, PREF_INSTALL_ROOT_COMMAND);
 		if (command != NULL)
@@ -2386,7 +2431,7 @@ update_module_ui (BasicAutotoolsPlugin *bb_plugin)
 		
 		module = escape_label (g_path_get_basename (dirname));
 		filename = escape_label (g_path_get_basename (bb_plugin->current_editor_filename));
-		has_makefile = directory_has_makefile (build_dirname) || project_has_configure (bb_plugin);
+		has_makefile = directory_has_makefile (build_dirname) || directory_has_makefile_am (bb_plugin, build_dirname);
 		g_free (build_dirname);
 		g_free (dirname);
 	}
@@ -2435,7 +2480,7 @@ update_project_ui (BasicAutotoolsPlugin *bb_plugin)
 	DEBUG_PRINT ("%s", "Updating project UI");
 	
 	has_project = bb_plugin->project_root_dir != NULL;
-	has_makefile = has_project && (directory_has_makefile (bb_plugin->project_build_dir) || project_has_configure (bb_plugin));
+	has_makefile = has_project && (directory_has_makefile (bb_plugin->project_build_dir) || directory_has_makefile_am (bb_plugin, bb_plugin->project_build_dir));
 
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN (bb_plugin)->shell, NULL);
 	action = anjuta_ui_get_action (ui, "ActionGroupBuild",
@@ -2594,7 +2639,7 @@ value_added_fm_current_file (AnjutaPlugin *plugin, const char *name,
 		dirname = g_strdup (filename);
 	else
 		dirname = g_path_get_dirname (filename);
-	makefile_exists = directory_has_makefile (dirname) || project_has_configure (ba_plugin);
+	makefile_exists = directory_has_makefile (dirname) || directory_has_makefile_am (ba_plugin, dirname);
 	g_free (dirname);
 	
 	if (!makefile_exists)
@@ -2658,7 +2703,7 @@ value_added_pm_current_uri (AnjutaPlugin *plugin, const char *name,
 		dirname = g_strdup (filename);
 	else
 		dirname = g_path_get_dirname (filename);
-	makefile_exists = directory_has_makefile (dirname) || project_has_configure (ba_plugin);
+	makefile_exists = directory_has_makefile (dirname) || directory_has_makefile_am (ba_plugin, dirname);
 	g_free (dirname);
 	
 	if (!makefile_exists)
@@ -2781,7 +2826,7 @@ on_update_indicators_idle (gpointer data)
 	/* If indicators are not yet updated in the editor, do it */
 	if (ba_plugin->current_editor_filename &&
 		IANJUTA_IS_INDICABLE (editor) &&
-		anjuta_preferences_get_int (anjuta_shell_get_preferences (plugin->shell,
+		anjuta_preferences_get_bool (anjuta_shell_get_preferences (plugin->shell,
 																  NULL),
 									PREF_INDICATORS_AUTOMATIC))
 	{
@@ -3298,26 +3343,35 @@ ibuilder_iface_init (IAnjutaBuilderIface *iface)
 /* IAnjutaPreferences implementation
  *---------------------------------------------------------------------------*/
 
-static GladeXML *gxml;
+static GtkBuilder *bxml;
 
 static void
 ipreferences_merge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError** e)
 {
+	GError* error = NULL;
 	GtkWidget *root_check;
 	GtkWidget *entry;
 		
 	/* Create the preferences page */
-	gxml = glade_xml_new (GLADE_FILE, BUILD_PREFS_DIALOG, NULL);
-	root_check = glade_xml_get_widget(gxml, INSTALL_ROOT_CHECK);
-	entry = glade_xml_get_widget(gxml, INSTALL_ROOT_ENTRY);
+	bxml =  gtk_builder_new();
+
+	if (!gtk_builder_add_from_file (bxml, BUILDER_FILE, &error))
+	{
+		g_warning ("Couldn't load builder file: %s", error->message);
+		g_error_free (error);
+	}
+
+	root_check = GTK_WIDGET (gtk_builder_get_object (bxml, INSTALL_ROOT_CHECK));
+	entry = GTK_WIDGET (gtk_builder_get_object (bxml, INSTALL_ROOT_ENTRY));
 	g_signal_connect(G_OBJECT(root_check), "toggled", G_CALLBACK(on_root_check_toggled), entry);
 	on_root_check_toggled (root_check, entry);
-	root_check = glade_xml_get_widget(gxml, PARALLEL_MAKE_CHECK);
-	entry = glade_xml_get_widget(gxml, PARALLEL_MAKE_SPIN);
+
+	root_check = GTK_WIDGET (gtk_builder_get_object (bxml, PARALLEL_MAKE_CHECK));
+	entry = GTK_WIDGET (gtk_builder_get_object (bxml, PARALLEL_MAKE_SPIN));
 	g_signal_connect(G_OBJECT(root_check), "toggled", G_CALLBACK(on_root_check_toggled), entry);
 	on_root_check_toggled (root_check, entry);
 	
-	anjuta_preferences_add_page (prefs, gxml, BUILD_PREFS_ROOT, _("Build Autotools"),  ICON_FILE);
+	anjuta_preferences_add_from_builder (prefs, bxml, BUILD_PREFS_ROOT, _("Build Autotools"),  ICON_FILE);
 }
 
 static void
@@ -3326,18 +3380,19 @@ ipreferences_unmerge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError
 	GtkWidget *root_check;
 	GtkWidget *entry;
 
-	root_check = glade_xml_get_widget(gxml, INSTALL_ROOT_CHECK);
-	entry = glade_xml_get_widget(gxml, INSTALL_ROOT_ENTRY);
+	root_check = GTK_WIDGET (gtk_builder_get_object (bxml, INSTALL_ROOT_CHECK));
+	entry = GTK_WIDGET (gtk_builder_get_object (bxml, INSTALL_ROOT_ENTRY));
 	g_signal_handlers_disconnect_by_func(G_OBJECT(root_check),
 		G_CALLBACK(on_root_check_toggled), entry);
-	root_check = glade_xml_get_widget(gxml, PARALLEL_MAKE_CHECK);
-	entry = glade_xml_get_widget(gxml, PARALLEL_MAKE_SPIN);
+
+	root_check = GTK_WIDGET (gtk_builder_get_object (bxml, PARALLEL_MAKE_CHECK));
+	entry = GTK_WIDGET (gtk_builder_get_object (bxml, PARALLEL_MAKE_SPIN));
 	g_signal_handlers_disconnect_by_func(G_OBJECT(root_check),
 		G_CALLBACK(on_root_check_toggled), entry);
 		
 	anjuta_preferences_remove_page(prefs, _("Build Autotools"));
 	
-	g_object_unref (gxml);
+	g_object_unref (bxml);
 }
 
 static void
