@@ -12,7 +12,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef PLUGIN_H
@@ -24,7 +24,15 @@
 
 //#include "macro-db.h"
 
-#define GLADE_FILE PACKAGE_DATA_DIR"/glade/anjuta-macro.glade"
+#define GLADE_FILE PACKAGE_DATA_DIR"/glade/anjuta-macro.ui"
+
+extern GType macro_plugin_get_type (GTypeModule *module);
+#define ANJUTA_TYPE_PLUGIN_MACRO         (macro_plugin_get_type (NULL))
+#define ANJUTA_PLUGIN_MACRO(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), ANJUTA_TYPE_PLUGIN_MACRO, MacroPlugin))
+#define ANJUTA_PLUGIN_MACRO_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST ((k), ANJUTA_TYPE_PLUGIN_MACRO, MacroPluginClass))
+#define ANJUTA_IS_PLUGIN_MACRO(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), ANJUTA_TYPE_PLUGIN_MACRO))
+#define ANJUTA_IS_PLUGIN_MACRO_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), ANJUTA_TYPE_PLUGIN_MACRO))
+#define ANJUTA_PLUGIN_MACRO_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), ANJUTA_TYPE_PLUGIN_MACRO, MacroPluginClass))
 
 typedef struct _MacroPlugin MacroPlugin;
 typedef struct _MacroPluginClass MacroPluginClass;
@@ -32,8 +40,13 @@ typedef struct _MacroPluginClass MacroPluginClass;
 struct _MacroPlugin
 {
 	AnjutaPlugin parent;
+	
+	/* Merge id */
 	gint uiid;
 
+	/* Action group */
+	GtkActionGroup *action_group;
+	
 	/* Watch IDs */
 	gint editor_watch_id;
 
