@@ -12,13 +12,12 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include <libgnomevfs/gnome-vfs.h>
-
 #include <libanjuta/anjuta-utils.h>
 #include <libanjuta/anjuta-debug.h>
+#include <libanjuta/anjuta-preferences.h>
 #include <libanjuta/interfaces/ianjuta-message-view.h>
 
 #include "message-view.h"
@@ -30,24 +29,24 @@ struct _MessageViewPrivate
 	gchar *line_buffer;
 
 	GtkWidget *tree_view;
-
-	AnjutaPreferences* prefs;
+	GtkTreeModel *model;
+	GtkTreeModel *filter;
+	
 	GtkWidget *popup_menu;
 	
 	gint adj_chgd_hdlr;
 	
+	/* Messages filter buttons */
+	GtkWidget *normal, *info, *warn, *error;
+	guint normal_count, info_count, warn_count, error_count;
+
 	/* Properties */
 	gchar *label;
 	gchar *pixmap;
 	gboolean highlite;
 	
-	GdkRectangle tooltip_rect;
-	GtkWidget *tooltip_window;
-	gulong tooltip_timeout;
-	PangoLayout *tooltip_layout;
-	
 	/* gconf notification ids */
-	GList *gconf_notify_ids;
+	GList *notify_ids;
 };
 
 typedef struct
@@ -80,6 +79,11 @@ static gpointer parent_class;
 static void prefs_init (MessageView *mview);
 static void prefs_finalize (MessageView *mview);
 
+static gboolean
+message_view_tree_view_filter (GtkTreeModel *model,
+							   GtkTreeIter  *iter,
+							   gpointer      data);
+
 /* Ask the user for an uri name */
 static gchar *
 ask_user_for_save_uri (GtkWindow* parent)
@@ -110,7 +114,7 @@ static Message*
 message_new (IAnjutaMessageViewType type, const gchar *summary,
 			 const gchar *details)
 {
-	/* DEBUG_PRINT ("Creating message"); */
+	/* DEBUG_PRINT ("%s", "Creating message"); */
 	Message *message = g_new0 (Message, 1);
 	message->type = type;
 	if (summary)
@@ -129,7 +133,7 @@ message_copy (const Message *src)
 static void
 message_free (Message *message)
 {
-	/* DEBUG_PRINT ("Freeing message"); */
+	/* DEBUG_PRINT ("%s", "Freeing message"); */
 	g_free (message->summary);
 	g_free (message->details);
 	g_free (message);
@@ -217,20 +221,19 @@ escape_string (const gchar *str)
 	return g_string_free (gstr, FALSE);
 }
 
-/* Tooltip operations -- taken from gtodo */
-
-static gchar *
-tooltip_get_display_text (MessageView *view)
+static gboolean
+message_view_query_tooltip (GtkWidget* widget, gint x, gint y, gboolean keyboard,
+						 GtkTooltip* tooltip)
 {
 	GtkTreePath *path;
 	GtkTreeIter iter;
 	GtkTreeModel *model;
+	MessageView* view = MESSAGE_VIEW(widget);
 	
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (view->privat->tree_view));
+	model = view->privat->model;
 	
 	if (gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW(view->privat->tree_view),
-		view->privat->tooltip_rect.x, view->privat->tooltip_rect.y,
-		&path, NULL, NULL, NULL))
+		x, y, &path, NULL, NULL, NULL))
 	{
 		Message *message;
 		gchar *text, *title, *desc;
@@ -242,7 +245,7 @@ tooltip_get_display_text (MessageView *view)
 		if (!message->details || !message->summary ||
 			strlen (message->details) <= 0 ||
 			strlen (message->summary) <= 0)
-			return NULL;
+			return FALSE;
 		
 		title = escape_string (message->summary);
 		desc = escape_string (message->details);
@@ -251,186 +254,13 @@ tooltip_get_display_text (MessageView *view)
 		g_free (title);
 		g_free (desc);
 		
-		return text;
-	}
-	return NULL;
-}
-
-static void
-tooltip_paint (GtkWidget *widget, GdkEventExpose *event, MessageView *view)
-{
-	GtkStyle *style;
-	gchar *tooltiptext;
-
-	tooltiptext = tooltip_get_display_text (view);
-	
-	if (!tooltiptext)
-		tooltiptext = g_strdup (_("No message details"));
-
-	pango_layout_set_markup (view->privat->tooltip_layout,
-							 tooltiptext,
-							 strlen (tooltiptext));
-	pango_layout_set_wrap(view->privat->tooltip_layout, PANGO_WRAP_CHAR);
-	pango_layout_set_width(view->privat->tooltip_layout, 600000);
-	style = view->privat->tooltip_window->style;
-
-	gtk_paint_flat_box (style, view->privat->tooltip_window->window,
-						GTK_STATE_NORMAL, GTK_SHADOW_OUT,
-						NULL, view->privat->tooltip_window,
-						"tooltip", 0, 0, -1, -1);
-
-	gtk_paint_layout (style, view->privat->tooltip_window->window,
-					  GTK_STATE_NORMAL, TRUE,
-					  NULL, view->privat->tooltip_window,
-					  "tooltip", 4, 4, view->privat->tooltip_layout);
-	/*
-	   g_object_unref(layout);
-	   */
-	g_free(tooltiptext);
-	return;
-}
-
-static gboolean
-tooltip_timeout (MessageView *view)
-{
-	gint scr_w,scr_h, w, h, x, y;
-	gchar *tooltiptext;
-
-	tooltiptext = tooltip_get_display_text (view);
-	
-	if (!tooltiptext)
-		tooltiptext = g_strdup (_("No message details"));
-	
-	view->privat->tooltip_window = gtk_window_new (GTK_WINDOW_POPUP);
-	view->privat->tooltip_window->parent = view->privat->tree_view;
-	gtk_widget_set_app_paintable (view->privat->tooltip_window, TRUE);
-	gtk_window_set_resizable (GTK_WINDOW(view->privat->tooltip_window), FALSE);
-	gtk_widget_set_name (view->privat->tooltip_window, "gtk-tooltips");
-	g_signal_connect (G_OBJECT(view->privat->tooltip_window), "expose_event",
-					  G_CALLBACK(tooltip_paint), view);
-	gtk_widget_ensure_style (view->privat->tooltip_window);
-
-	view->privat->tooltip_layout =
-		gtk_widget_create_pango_layout (view->privat->tooltip_window, NULL);
-	pango_layout_set_wrap (view->privat->tooltip_layout, PANGO_WRAP_CHAR);
-	pango_layout_set_width (view->privat->tooltip_layout, 600000);
-	pango_layout_set_markup (view->privat->tooltip_layout, tooltiptext,
-							 strlen (tooltiptext));
-	scr_w = gdk_screen_width();
-	scr_h = gdk_screen_height();
-	pango_layout_get_size (view->privat->tooltip_layout, &w, &h);
-	w = PANGO_PIXELS(w) + 8;
-	h = PANGO_PIXELS(h) + 8;
-
-	gdk_window_get_pointer (NULL, &x, &y, NULL);
-	if (GTK_WIDGET_NO_WINDOW (view->privat->tree_view))
-		y += view->privat->tree_view->allocation.y;
-
-	x -= ((w >> 1) + 4);
-
-	if ((x + w) > scr_w)
-		x -= (x + w) - scr_w;
-	else if (x < 0)
-		x = 0;
-
-	if ((y + h + 4) > scr_h)
-		y = y - h;
-	else
-		y = y + 6;
-	/*
-	   g_object_unref(layout);
-	   */
-	gtk_widget_set_size_request (view->privat->tooltip_window, w, h);
-	gtk_window_move (GTK_WINDOW (view->privat->tooltip_window), x, y);
-	gtk_widget_show (view->privat->tooltip_window);
-	g_free (tooltiptext);
-	
-	return FALSE;
-}
-
-static gboolean
-tooltip_motion_cb (GtkWidget *tv, GdkEventMotion *event, MessageView *view)
-{
-	GtkTreePath *path;
-	
-	if (view->privat->tooltip_rect.y == 0 &&
-		view->privat->tooltip_rect.height == 0 &&
-		view->privat->tooltip_timeout)
-	{
-		g_source_remove (view->privat->tooltip_timeout);
-		view->privat->tooltip_timeout = 0;
-		if (view->privat->tooltip_window) {
-			gtk_widget_destroy (view->privat->tooltip_window);
-			view->privat->tooltip_window = NULL;
-		}
-		return FALSE;
-	}
-	if (view->privat->tooltip_timeout) {
-		if (((int)event->y > view->privat->tooltip_rect.y) &&
-			(((int)event->y - view->privat->tooltip_rect.height)
-				< view->privat->tooltip_rect.y))
-			return FALSE;
-
-		if(event->y == 0)
-		{
-			g_source_remove (view->privat->tooltip_timeout);
-			view->privat->tooltip_timeout = 0;
-			return FALSE;
-		}
-		/* We've left the cell.  Remove the timeout and create a new one below */
-		if (view->privat->tooltip_window) {
-			gtk_widget_destroy (view->privat->tooltip_window);
-			view->privat->tooltip_window = NULL;
-		}
-		g_source_remove (view->privat->tooltip_timeout);
-		view->privat->tooltip_timeout = 0;
-	}
-
-	if (gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW(view->privat->tree_view),
-									   event->x, event->y, &path,
-									   NULL, NULL, NULL))
-	{
-		GtkTreeSelection *selection;
-		
-		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW(view->privat->tree_view));
-		if (gtk_tree_selection_path_is_selected (selection, path))
-		{
-			gtk_tree_view_get_cell_area (GTK_TREE_VIEW (view->privat->tree_view),
-										 path, NULL, &view->privat->tooltip_rect);
-			
-			if (view->privat->tooltip_rect.y != 0 &&
-				view->privat->tooltip_rect.height != 0)
-			{
-				gchar *tooltiptext;
-				
-				tooltiptext = tooltip_get_display_text (view);
-				if (tooltiptext == NULL)
-					return FALSE;
-				g_free (tooltiptext);
-				
-				view->privat->tooltip_timeout =
-					g_timeout_add (500, (GSourceFunc) tooltip_timeout, view);
-			}
-		}
-		gtk_tree_path_free (path);
+		gtk_tooltip_set_markup (tooltip, text);
+		g_free (text);
+		return TRUE;
 	}
 	return FALSE;
 }
 
-static void
-tooltip_leave_cb (GtkWidget *w, GdkEventCrossing *e, MessageView *view)
-{
-	if (view->privat->tooltip_timeout) {
-		g_source_remove (view->privat->tooltip_timeout);
-		view->privat->tooltip_timeout = 0;
-	}
-	if (view->privat->tooltip_window) {
-		gtk_widget_destroy (view->privat->tooltip_window);
-		g_object_unref (view->privat->tooltip_layout);
-		view->privat->tooltip_window = NULL;
-	}
-}
-
 /* MessageView signal callbacks */
 /* Send a signal if a message was double-clicked or ENTER or SPACE was pressed */
 static gboolean
@@ -494,6 +324,14 @@ on_message_event (GObject* object, GdkEvent* event, gpointer data)
 	return FALSE;
 }
 
+static void
+on_filter_buttons_toggled (GtkToggleButton *toggle, gpointer user_data) 
+{
+	MessageView *msgview = MESSAGE_VIEW (user_data);
+	
+	gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (msgview->privat->filter));
+}
+
 static void 
 on_adjustment_changed (GtkAdjustment* adj, gpointer data)
 {
@@ -598,25 +436,16 @@ static void
 message_view_dispose (GObject *obj)
 {
 	MessageView *mview = MESSAGE_VIEW (obj);
-	if (mview->privat->gconf_notify_ids)
+	if (mview->privat->notify_ids)
 	{
 		prefs_finalize (mview);
-		mview->privat->gconf_notify_ids = NULL;
-	}
-	if (mview->privat->tooltip_timeout) {
-		g_source_remove (mview->privat->tooltip_timeout);
-		mview->privat->tooltip_timeout = 0;
-	}
-	if (mview->privat->tooltip_window) {
-		gtk_widget_destroy (mview->privat->tooltip_window);
-		g_object_unref (mview->privat->tooltip_layout);
-		mview->privat->tooltip_window = NULL;
+		mview->privat->notify_ids = NULL;
 	}
 	if (mview->privat->tree_view)
 	{
 		mview->privat->tree_view = NULL;
 	}
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (G_OBJECT(obj)));
+	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
 
 static void
@@ -627,38 +456,115 @@ message_view_finalize (GObject *obj)
 	g_free (mview->privat->label);
 	g_free (mview->privat->pixmap);
 	g_free (mview->privat);
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (G_OBJECT(obj)));
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 static void
 message_view_instance_init (MessageView * self)
 {
+	GtkWidget *vbox;
+	GtkWidget *filter_buttons_box;
 	GtkWidget *scrolled_win;
 	GtkCellRenderer *renderer;
 	GtkCellRenderer *renderer_pixbuf;
 	GtkTreeViewColumn *column;
 	GtkTreeViewColumn *column_pixbuf;
 	GtkTreeSelection *select;
-	GtkListStore *model;
+	GtkListStore *model;	
 	GtkAdjustment* adj;
-
+ 
 	g_return_if_fail(self != NULL);
 	self->privat = g_new0 (MessageViewPrivate, 1);
 
 	/* Init private data */
 	self->privat->line_buffer = g_strdup("");
+	self->privat->normal_count = 0;
+	self->privat->info_count = 0;
+	self->privat->warn_count = 0;
+	self->privat->error_count = 0;
 
+	/* Create filter buttons */
+	vbox = gtk_hbox_new (FALSE, 0);
+	filter_buttons_box = gtk_vbox_new (FALSE, 1);
+	
+	self->privat->normal = gtk_toggle_button_new_with_label (_("No Messages"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->privat->normal), TRUE);
+	gtk_button_set_focus_on_click (GTK_BUTTON (self->privat->normal), FALSE);
+	gtk_button_set_relief (GTK_BUTTON (self->privat->normal), GTK_RELIEF_HALF);
+	gtk_button_set_alignment (GTK_BUTTON (self->privat->normal), 0.0, 0.5);
+	gtk_widget_show (self->privat->normal);
+	g_signal_connect (G_OBJECT (self->privat->normal), "toggled",
+					  G_CALLBACK (on_filter_buttons_toggled), self);
+	
+	self->privat->info = gtk_toggle_button_new_with_label (_("No Infos"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->privat->info), TRUE);
+	gtk_button_set_focus_on_click (GTK_BUTTON (self->privat->info), FALSE);
+	gtk_button_set_relief (GTK_BUTTON (self->privat->info), GTK_RELIEF_HALF);
+	gtk_button_set_alignment (GTK_BUTTON (self->privat->info), 0.0, 0.5);
+	gtk_button_set_image (GTK_BUTTON (self->privat->info), 
+						  gtk_image_new_from_stock (GTK_STOCK_INFO, 
+													GTK_ICON_SIZE_BUTTON));
+	gtk_widget_show (self->privat->info);
+	g_signal_connect (G_OBJECT (self->privat->info), "toggled",
+					  G_CALLBACK (on_filter_buttons_toggled), self);
+	
+	self->privat->warn = gtk_toggle_button_new_with_label (_("No Warnings"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->privat->warn), TRUE);
+	gtk_button_set_focus_on_click (GTK_BUTTON (self->privat->warn), FALSE);
+	gtk_button_set_relief (GTK_BUTTON (self->privat->warn), GTK_RELIEF_HALF);
+	gtk_button_set_alignment (GTK_BUTTON (self->privat->warn), 0.0, 0.5);
+	/* FIXME: There is not GTK_STOCK_DIALOG_WARNING. */
+	gtk_button_set_image (GTK_BUTTON (self->privat->warn), 
+						  gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING, 
+													GTK_ICON_SIZE_BUTTON));
+	gtk_widget_show (self->privat->warn);
+	g_signal_connect (G_OBJECT (self->privat->warn), "toggled",
+					  G_CALLBACK (on_filter_buttons_toggled), self);
+	
+	self->privat->error = gtk_toggle_button_new_with_label (_("No Errors"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->privat->error), TRUE);
+	gtk_button_set_focus_on_click (GTK_BUTTON (self->privat->error), FALSE);
+	gtk_button_set_relief (GTK_BUTTON (self->privat->error), GTK_RELIEF_HALF);
+	gtk_button_set_alignment (GTK_BUTTON (self->privat->error), 0.0, 0.5);
+	gtk_button_set_image (GTK_BUTTON (self->privat->error), 
+						  gtk_image_new_from_stock (GTK_STOCK_STOP, 
+													GTK_ICON_SIZE_BUTTON));
+	gtk_widget_show (self->privat->error);
+	g_signal_connect (G_OBJECT (self->privat->error), "toggled",
+					  G_CALLBACK (on_filter_buttons_toggled), self);
+	
+	gtk_box_pack_start (GTK_BOX (filter_buttons_box), GTK_WIDGET (self->privat->normal),
+						FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (filter_buttons_box), GTK_WIDGET (self->privat->info),
+						FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (filter_buttons_box), GTK_WIDGET (self->privat->warn),
+						FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (filter_buttons_box), GTK_WIDGET (self->privat->error),
+						FALSE, FALSE, 0);
+	
+	gtk_widget_show (filter_buttons_box);
+	
+	
 	/* Create the tree widget */
-	model = gtk_list_store_new (N_COLUMNS, GDK_TYPE_COLOR,
+	model = gtk_list_store_new (N_COLUMNS, G_TYPE_STRING,
 								G_TYPE_STRING, MESSAGE_TYPE,  G_TYPE_STRING);
-	self->privat->tree_view =
-		gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
+	self->privat->model = GTK_TREE_MODEL (model);
+	
+	/* message filter */
+	self->privat->filter = gtk_tree_model_filter_new (GTK_TREE_MODEL (model), NULL);
+	gtk_tree_model_filter_set_visible_func (GTK_TREE_MODEL_FILTER (self->privat->filter), 
+											message_view_tree_view_filter,
+											self, NULL);
+	
+	self->privat->tree_view = 
+		gtk_tree_view_new_with_model (GTK_TREE_MODEL (self->privat->filter));
 	gtk_widget_show (self->privat->tree_view);
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW
 									   (self->privat->tree_view), FALSE);
 
 	/* Create pixbuf column */
 	renderer_pixbuf = gtk_cell_renderer_pixbuf_new ();
+	g_object_set (G_OBJECT(renderer_pixbuf), "stock-size", GTK_ICON_SIZE_MENU, NULL);
 	column_pixbuf = gtk_tree_view_column_new ();
 	gtk_tree_view_column_set_title (column_pixbuf, _("Icon"));
 	gtk_tree_view_column_pack_start (column_pixbuf, renderer_pixbuf, TRUE);
@@ -672,10 +578,11 @@ message_view_instance_init (MessageView * self)
 	g_object_set (renderer, "yalign", 0.0, "wrap-mode", PANGO_WRAP_WORD,
 				  "wrap-width", 1000, NULL);
 	column = gtk_tree_view_column_new ();
+
 	gtk_tree_view_column_pack_start (column, renderer, TRUE);
 	gtk_tree_view_column_set_title (column, _("Messages"));
 	gtk_tree_view_column_add_attribute
-		(column, renderer, "foreground-gdk", COLUMN_COLOR);
+		(column, renderer, "foreground", COLUMN_COLOR);
 	gtk_tree_view_column_add_attribute
 		(column, renderer, "markup", COLUMN_SUMMARY);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (self->privat->tree_view),
@@ -685,7 +592,7 @@ message_view_instance_init (MessageView * self)
 	select = gtk_tree_view_get_selection
 		(GTK_TREE_VIEW (self->privat->tree_view));
 	gtk_tree_selection_set_mode (select, GTK_SELECTION_BROWSE);
-
+	
 	/* Add tree view to a scrolled window */
 	scrolled_win = gtk_scrolled_window_new (NULL, NULL);
 	gtk_container_add (GTK_CONTAINER (scrolled_win),
@@ -702,16 +609,27 @@ message_view_instance_init (MessageView * self)
 					 G_CALLBACK(on_adjustment_value_changed), self);
 
 	/* Add it to the dockitem */
-	gtk_container_add (GTK_CONTAINER (self), scrolled_win);
+	if (gtk_widget_get_default_direction () == GTK_TEXT_DIR_LTR) {
+		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (scrolled_win),
+							TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (filter_buttons_box),
+							FALSE, FALSE, 0);
+	} else {
+		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (filter_buttons_box),
+							FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (scrolled_win),
+							TRUE, TRUE, 0);
+	}
+	
+	gtk_widget_show (vbox);
+	gtk_container_add (GTK_CONTAINER (self), vbox);
 	
 	/* Connect signals */
 	g_signal_connect (G_OBJECT(self->privat->tree_view), "event", 
 					  G_CALLBACK (on_message_event), self);
-	g_signal_connect (G_OBJECT (self->privat->tree_view), "motion-notify-event",
-					  G_CALLBACK (tooltip_motion_cb), self);
-	g_signal_connect (G_OBJECT (self->privat->tree_view), "leave-notify-event",
-					  G_CALLBACK (tooltip_leave_cb), self);
-	g_object_unref (model);
+	
+	g_object_set (G_OBJECT(self), "has-tooltip", TRUE, NULL);
+
 }
 
 static void
@@ -721,6 +639,7 @@ message_view_class_init (MessageViewClass * klass)
 	GParamSpec *message_view_spec_pixmap;
 	GParamSpec *message_view_spec_highlite;
 	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
+	GtkWidgetClass* widget_class = GTK_WIDGET_CLASS (klass);
 	
 	parent_class = g_type_class_peek_parent (klass);
 	gobject_class->set_property = message_view_set_property;
@@ -728,6 +647,9 @@ message_view_class_init (MessageViewClass * klass)
 	gobject_class->finalize = message_view_finalize;
 	gobject_class->dispose = message_view_dispose;
 	
+	widget_class->query_tooltip = message_view_query_tooltip;
+
+	
 	message_view_spec_label = g_param_spec_string ("label",
 						       "Label of the view",
 						       "Used to decorate the view,"
@@ -760,10 +682,9 @@ message_view_class_init (MessageViewClass * klass)
 
 /* Returns a new message-view instance */
 GtkWidget *
-message_view_new (AnjutaPreferences* prefs, GtkWidget* popup_menu)
+message_view_new (GtkWidget* popup_menu)
 {
 	MessageView * mv = MESSAGE_VIEW (g_object_new (message_view_get_type (), NULL));
-	mv->privat->prefs = prefs;
 	mv->privat->popup_menu = popup_menu;
 	prefs_init (mv);
 	return GTK_WIDGET(mv);
@@ -786,7 +707,7 @@ message_view_serialize (MessageView *view, AnjutaSerializer *serializer)
 		return FALSE;
 	
 	/* Serialize individual messages */
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (view->privat->tree_view));
+	model = view->privat->model;
 	
 	if (!anjuta_serializer_write_int (serializer, "messages",
 									  gtk_tree_model_iter_n_children (model, NULL)))
@@ -826,7 +747,7 @@ message_view_deserialize (MessageView *view, AnjutaSerializer *serializer)
 		return FALSE;
 	
 	/* Create individual messages */
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (view->privat->tree_view));
+	model = view->privat->model;
 	gtk_list_store_clear (GTK_LIST_STORE (model));
 	
 	if (!anjuta_serializer_read_int (serializer, "messages", &messages))
@@ -855,8 +776,7 @@ void message_view_next(MessageView* view)
 	GtkTreeModel *model;
 	GtkTreeSelection *select;
 
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW
-					 (view->privat->tree_view));
+	model = view->privat->model;
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW
 					      (view->privat->tree_view));
 
@@ -870,8 +790,8 @@ void message_view_next(MessageView* view)
 		Message *message;
 		gtk_tree_model_get (model, &iter, COLUMN_MESSAGE,
 							&message, -1);
-		if (message->type != IANJUTA_MESSAGE_VIEW_TYPE_NORMAL
-			&& message->type != IANJUTA_MESSAGE_VIEW_TYPE_INFO)
+		if (message->type == IANJUTA_MESSAGE_VIEW_TYPE_WARNING
+			|| message->type == IANJUTA_MESSAGE_VIEW_TYPE_ERROR)
 		{
 			const gchar* message;
 			gtk_tree_selection_select_iter (select, &iter);
@@ -887,8 +807,8 @@ void message_view_next(MessageView* view)
 				gtk_tree_path_free (path);
 				g_signal_emit_by_name (G_OBJECT (view), "message_clicked", 
 									   message);
+				break;
 			}
-			break;
 		}
 	}
 }
@@ -900,8 +820,7 @@ void message_view_previous(MessageView* view)
 	GtkTreeSelection *select;
 	GtkTreePath *path;
 
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW
-					 (view->privat->tree_view));
+	model = view->privat->model;
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW
 					      (view->privat->tree_view));
 	
@@ -920,8 +839,8 @@ void message_view_previous(MessageView* view)
 		gtk_tree_model_get_iter(model, &iter, path);
 		gtk_tree_model_get (model, &iter, COLUMN_MESSAGE,
 							&message, -1);
-		if (message->type != IANJUTA_MESSAGE_VIEW_TYPE_NORMAL
-			&& message->type != IANJUTA_MESSAGE_VIEW_TYPE_INFO)
+		if (message->type == IANJUTA_MESSAGE_VIEW_TYPE_WARNING
+			|| message->type == IANJUTA_MESSAGE_VIEW_TYPE_ERROR)
 		{
 			const gchar* message;
 			
@@ -938,8 +857,8 @@ void message_view_previous(MessageView* view)
 				gtk_tree_path_free (path);
 				g_signal_emit_by_name (G_OBJECT (view), "message_clicked", 
 									   message);
+				break;
 			}
-			break;
 		}
 	}
 	gtk_tree_path_free (path);
@@ -947,53 +866,63 @@ void message_view_previous(MessageView* view)
 
 static gboolean message_view_save_as(MessageView* view, gchar* uri)
 {
-	GnomeVFSHandle* handle;
+	GFile *file;
+	GOutputStream *os;
 	GtkTreeIter iter;
 	GtkTreeModel *model;
 	gboolean ok;
 
 	if (uri == NULL) return FALSE;
 
+	file = g_file_new_for_uri (uri);
+	os = G_OUTPUT_STREAM (
+			g_file_replace (file, NULL, 
+				FALSE,
+				G_FILE_CREATE_NONE,
+				NULL,
+				NULL));
 	/* Create file */
-	if (gnome_vfs_create (&handle, uri, GNOME_VFS_OPEN_WRITE, FALSE, 0664) != GNOME_VFS_OK)
+	if (os == NULL)
 	{
+		g_object_unref (file);
 		return FALSE;
 	}
 
 	/* Save all lines of message view */	
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (view->privat->tree_view));
+	model = view->privat->model;
 
 	ok = TRUE;
 	gtk_tree_model_get_iter_first (model, &iter);
 	while (gtk_tree_model_iter_next (model, &iter))
 	{
 		Message *message;
-		GnomeVFSFileSize written;
 
 		gtk_tree_model_get (model, &iter, COLUMN_MESSAGE, &message, -1);
 		if (message)
 		{
 			if (message->details && (strlen (message->details) > 0))
 			{
-				if (gnome_vfs_write (handle, message->details, strlen (message->details), &written) != GNOME_VFS_OK)
+				if (!g_output_stream_write (os, message->details, strlen (message->details), NULL, NULL))
 				{
 					ok = FALSE;
 				}
 			}
 			else
 			{
-				if (gnome_vfs_write (handle, message->summary, strlen (message->summary), &written) != GNOME_VFS_OK)
+				if (!g_output_stream_write (os, message->summary, strlen (message->summary), NULL, NULL))
 				{
 					ok = FALSE;
 				}
 			}
-			if (gnome_vfs_write (handle, "\n", 1, &written) != GNOME_VFS_OK)
+			if (!g_output_stream_write (os, "\n", 1, NULL, NULL))
 			{
 				ok = FALSE;
 			}
 		}
 	}
-	gnome_vfs_close (handle);
+	g_output_stream_close (os, NULL, NULL);
+	g_object_unref (os);
+	g_object_unref (file);
 
 	return ok;
 }
@@ -1016,19 +945,56 @@ void message_view_save(MessageView* view)
 	}
 }
 
+void message_view_copy(MessageView* view)
+{
+	GtkTreeIter iter;
+	GtkTreeModel *model;
+	GtkTreeSelection *select;
+
+	model = view->privat->model;
+	select = gtk_tree_view_get_selection (GTK_TREE_VIEW
+					      (view->privat->tree_view));
+	
+	if (gtk_tree_selection_get_selected (select, &model, &iter))
+	{
+		Message *message;
+		const gchar *text;
+		GtkClipboard *clipboard;
+		
+		gtk_tree_model_get (model, &iter, COLUMN_MESSAGE, &message, -1); 
+		
+		if (message->details && (*message->details != '\0'))
+		{
+			text = message->details;
+		}
+		else if (message->summary && (*message->summary != '\0'))
+		{
+			text = message->summary;
+		}
+		else
+		{
+			/* No message */
+			return;
+		}
+		
+		clipboard = gtk_widget_get_clipboard (GTK_WIDGET (view), GDK_SELECTION_CLIPBOARD);
+	
+		gtk_clipboard_set_text (clipboard, text, -1);
+	}
+}
+
 /* Preferences notifications */
 static void
 pref_change_color (MessageView *mview, IAnjutaMessageViewType type,
 				   const gchar *color_pref_key)
 {
-	GdkColor *color;
+	gchar* color;
 	GtkListStore *store;
 	GtkTreeIter iter;
 	gboolean success;
 	
-	color = anjuta_util_convert_color (mview->privat->prefs, color_pref_key);
-	store = GTK_LIST_STORE (gtk_tree_view_get_model
-				(GTK_TREE_VIEW (mview->privat->tree_view)));
+	color = anjuta_preferences_get (anjuta_preferences_default(), color_pref_key);
+	store = GTK_LIST_STORE (mview->privat->model);
 	success = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (store), &iter);
 	while (success)
 	{
@@ -1044,60 +1010,49 @@ pref_change_color (MessageView *mview, IAnjutaMessageViewType type,
 	g_free(color);
 }
 
-static void
-on_gconf_notify_color_info (GConfClient *gclient, guint cnxn_id,
-							GConfEntry *entry, gpointer user_data)
-{
-	pref_change_color (MESSAGE_VIEW (user_data),
-					   IANJUTA_MESSAGE_VIEW_TYPE_INFO,
-					   "messages.color.info");
-}
 
 static void
-on_gconf_notify_color_warning (GConfClient *gclient, guint cnxn_id,
-							   GConfEntry *entry, gpointer user_data)
+on_notify_color (AnjutaPreferences* prefs, const gchar* key,
+                 const gchar* value, gpointer user_data)
 {
 	pref_change_color (MESSAGE_VIEW (user_data),
 					   IANJUTA_MESSAGE_VIEW_TYPE_WARNING,
-					   "messages.color.warning");
+					   key);
 }
 
-static void
-on_gconf_notify_color_error (GConfClient *gclient, guint cnxn_id,
-							 GConfEntry *entry, gpointer user_data)
-{
-	pref_change_color (MESSAGE_VIEW (user_data),
-					   IANJUTA_MESSAGE_VIEW_TYPE_ERROR,
-					   "messages.color.error");
-}
-
-#define REGISTER_NOTIFY(key, func) \
-	notify_id = anjuta_preferences_notify_add (mview->privat->prefs, \
-											   key, func, mview, NULL); \
-	mview->privat->gconf_notify_ids = g_list_prepend (mview->privat->gconf_notify_ids, \
-										   GINT_TO_POINTER(notify_id));
 static void
 prefs_init (MessageView *mview)
 {
-	guint notify_id;
-	REGISTER_NOTIFY ("messages.color.info", on_gconf_notify_color_info);
-	REGISTER_NOTIFY ("messages.color.warning", on_gconf_notify_color_warning);
-	REGISTER_NOTIFY ("messages.color.error", on_gconf_notify_color_error);
+	gint id;
+	id = anjuta_preferences_notify_add_string (anjuta_preferences_default (),
+	                                           "messages.color.error",
+	                                           on_notify_color,
+	                                           mview,
+	                                           NULL);
+	mview->privat->notify_ids = g_list_append (mview->privat->notify_ids,
+	                                           GINT_TO_POINTER (id));	
+	id = anjuta_preferences_notify_add_string (anjuta_preferences_default (),
+	                                      "messages.color.warning",
+	                                      on_notify_color,
+	                                      mview,
+	                                      NULL);
+	mview->privat->notify_ids = g_list_append (mview->privat->notify_ids,
+	                                         GINT_TO_POINTER (id));
 }
 
 static void
 prefs_finalize (MessageView *mview)
 {
 	GList *node;
-	node = mview->privat->gconf_notify_ids;
+	node = mview->privat->notify_ids;
 	while (node)
 	{
-		anjuta_preferences_notify_remove (mview->privat->prefs,
+		anjuta_preferences_notify_remove (anjuta_preferences_default(),
 										  GPOINTER_TO_INT (node->data));
 		node = g_list_next (node);
 	}
-	g_list_free (mview->privat->gconf_notify_ids);
-	mview->privat->gconf_notify_ids = NULL;
+	g_list_free (mview->privat->notify_ids);
+	mview->privat->notify_ids = NULL;
 }
 
 /* IAnjutaMessageView interface implementation */
@@ -1121,15 +1076,6 @@ imessage_view_buffer_append (IAnjutaMessageView * message_view,
 	/* Check if message contains newlines */
 	for (cur_char = 0; cur_char < len; cur_char++)
 	{		
-		/* Replace "\\\n" with " " */
-		if (message[cur_char] == '\\' && cur_char < len - 1 &&
-			message[cur_char+1] == '\n')
-		{
-			add_char(&view->privat->line_buffer, ' ');
-			cur_char++;
-			continue;
-		}
-
 		/* Is newline => print line */
 		if (message[cur_char] != '\n')
 		{
@@ -1145,6 +1091,36 @@ imessage_view_buffer_append (IAnjutaMessageView * message_view,
 	}
 }
 
+static void 
+update_button_labels (MessageView* view)
+{
+	gchar* temp;
+	
+	temp = g_strdup_printf(ngettext ("%d Message", "%d Messages", 
+									 view->privat->normal_count),
+						   view->privat->normal_count);
+	gtk_button_set_label (GTK_BUTTON (view->privat->normal), temp);
+	g_free(temp);
+	
+	temp = g_strdup_printf(ngettext ("%d Info", "%d Infos", 
+									 view->privat->info_count),
+						   view->privat->info_count);
+	gtk_button_set_label (GTK_BUTTON (view->privat->info), temp);
+	g_free (temp);
+	temp = g_strdup_printf(ngettext ("%d Warning", "%d Warnings", 
+									 view->privat->warn_count),
+						   view->privat->warn_count);	
+	gtk_button_set_label (GTK_BUTTON (view->privat->warn), temp);
+	g_free (temp);
+	temp = g_strdup_printf(ngettext ("%d Error", "%d Errors", 
+									 view->privat->error_count),
+						   view->privat->error_count);	
+	gtk_button_set_label (GTK_BUTTON (view->privat->error), temp);
+	g_free (temp);
+	
+}
+
+
 static void
 imessage_view_append (IAnjutaMessageView *message_view,
 					  IAnjutaMessageViewType type,
@@ -1152,13 +1128,13 @@ imessage_view_append (IAnjutaMessageView *message_view,
 					  const gchar *details,
 					  GError ** e)
 {
-	GdkColor* color;
+	gchar* color;
 	GtkListStore *store;
 	GtkTreeIter iter;
 	gboolean highlite;
 	gchar *utf8_msg;
 	gchar *escaped_str;
-	gchar* stock_id;
+	gchar* stock_id = NULL;
 	
 	MessageView *view;
 	Message *message;
@@ -1176,29 +1152,31 @@ imessage_view_append (IAnjutaMessageView *message_view,
 		switch (message->type)
 		{
 			case IANJUTA_MESSAGE_VIEW_TYPE_INFO:
-				color = anjuta_util_convert_color(view->privat->prefs,
-									  "messages.color.info");
+				view->privat->info_count++;
 				stock_id = GTK_STOCK_INFO;
 				break;
 			case IANJUTA_MESSAGE_VIEW_TYPE_WARNING:
-				color = anjuta_util_convert_color(view->privat->prefs,
+				color = anjuta_preferences_get (anjuta_preferences_default(),
 									  "messages.color.warning");
 				/* FIXME: There is no GTK_STOCK_WARNING which would fit better here */
+				view->privat->warn_count++;
 				stock_id = GTK_STOCK_DIALOG_WARNING;
 				break;
 			case IANJUTA_MESSAGE_VIEW_TYPE_ERROR:
-				color = anjuta_util_convert_color(view->privat->prefs,
+				color = anjuta_preferences_get (anjuta_preferences_default(),
 									  "messages.color.error");
+				view->privat->error_count++;
 				stock_id = GTK_STOCK_STOP;
 				break;
 			default:
 				color = NULL;
+				view->privat->normal_count++;
 		}
 	}
-
+	update_button_labels (view);
+	
 	/* Add the message to the tree */
-	store = GTK_LIST_STORE (gtk_tree_view_get_model
-				(GTK_TREE_VIEW (view->privat->tree_view)));
+	store = GTK_LIST_STORE (view->privat->model);
 	gtk_list_store_append (store, &iter);
 
 	/*
@@ -1216,23 +1194,21 @@ imessage_view_append (IAnjutaMessageView *message_view,
 	} else {
 		escaped_str = escape_string (message->summary);
 	}
+	gtk_list_store_set (store, &iter,
+							COLUMN_SUMMARY, escaped_str,
+							COLUMN_MESSAGE, message,
+							-1);
 	if (color)
 	{
 		gtk_list_store_set (store, &iter,
-							COLUMN_COLOR, color,
-							COLUMN_SUMMARY, escaped_str,
-							COLUMN_MESSAGE, message,
-							COLUMN_PIXBUF, stock_id,
-							-1);
-	
-		/* Can we free the color when it's in the tree_view? */
-		// gdk_color_free (color);
-	} else {
-		gtk_list_store_set (store, &iter,
-							COLUMN_SUMMARY, escaped_str,
-							COLUMN_MESSAGE, message,
-							-1);
+							COLUMN_COLOR, color, -1);
 	}
+	if (stock_id)
+	{
+		gtk_list_store_set (store, &iter,
+							COLUMN_PIXBUF, stock_id, -1);
+	}
+	g_free(color);
 	message_free (message);
 	g_free (utf8_msg);
 	g_free (escaped_str);
@@ -1248,8 +1224,19 @@ imessage_view_clear (IAnjutaMessageView *message_view, GError **e)
 	g_return_if_fail (MESSAGE_IS_VIEW (message_view));
 	view = MESSAGE_VIEW (message_view);
 
-	store = GTK_LIST_STORE (gtk_tree_view_get_model
-				(GTK_TREE_VIEW (view->privat->tree_view)));
+	/* filter settings restart */
+	view->privat->normal_count = 0;	
+	view->privat->info_count = 0;
+	view->privat->warn_count = 0;
+	view->privat->error_count = 0;
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (view->privat->normal), TRUE);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (view->privat->info), TRUE);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (view->privat->warn), TRUE);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (view->privat->error), TRUE);
+	
+	update_button_labels (view);
+	
+	store = GTK_LIST_STORE (view->privat->model);
 	gtk_list_store_clear (store);
 }
 
@@ -1338,8 +1325,7 @@ imessage_view_get_all_messages (IAnjutaMessageView * message_view,
 	g_return_val_if_fail (MESSAGE_IS_VIEW (message_view), NULL);
 	
 	view = MESSAGE_VIEW (message_view);
-	store = GTK_LIST_STORE (gtk_tree_view_get_model
-				(GTK_TREE_VIEW (view->privat->tree_view)));
+	store = GTK_LIST_STORE (view->privat->model);
 	
 	if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (store), &iter))
 	{
@@ -1366,6 +1352,29 @@ imessage_view_iface_init (IAnjutaMessageViewIface *iface)
 	iface->get_all_messages = imessage_view_get_all_messages;
 }
 
+static gboolean
+message_view_tree_view_filter (GtkTreeModel *model, GtkTreeIter  *iter,
+							   gpointer      data)
+{
+	Message *msg;
+	MessageView *msgview;
+	
+	msgview = MESSAGE_VIEW (data);
+	gtk_tree_model_get (msgview->privat->model, iter, COLUMN_MESSAGE, &msg, -1);
+
+	if (msg != NULL) {
+		if (msg->type == IANJUTA_MESSAGE_VIEW_TYPE_NORMAL) {
+			return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (msgview->privat->normal));
+		} else if (msg->type == IANJUTA_MESSAGE_VIEW_TYPE_INFO) {
+			return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (msgview->privat->info));
+		} else if (msg->type == IANJUTA_MESSAGE_VIEW_TYPE_WARNING) {
+			return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (msgview->privat->warn));
+		} else if (msg->type == IANJUTA_MESSAGE_VIEW_TYPE_ERROR) {
+			return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (msgview->privat->error));
+		} else return TRUE;
+	} else return FALSE;
+}
+
 ANJUTA_TYPE_BEGIN(MessageView, message_view, GTK_TYPE_HBOX);
 ANJUTA_TYPE_ADD_INTERFACE(imessage_view, IANJUTA_TYPE_MESSAGE_VIEW);
 ANJUTA_TYPE_END;
