@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
  * plugin.h
- * Copyright (C) Massimo Cora' 2007 <maxcvs@email.it>
+ * Copyright (C) Massimo Cora' 2007-2008 <maxcvs@email.it>
  * 
  * plugin.h is free software.
  * 
@@ -28,7 +28,6 @@
 #include <libanjuta/anjuta-plugin.h>
 #include <libanjuta/anjuta-launcher.h>
 #include "symbol-db-engine.h"
-#include "symbol-db-engine-iterator.h"
 
 
 G_BEGIN_DECLS
@@ -52,15 +51,25 @@ typedef struct _SymbolDBPluginClass SymbolDBPluginClass;
 /* a sort of 'default' value for ctags executable. User must have it installed */
 #define CTAGS_PATH			"/usr/bin/ctags"
 
-struct _SymbolDBPlugin{
+struct _SymbolDBPlugin {
 	AnjutaPlugin parent;
 	AnjutaUI *ui;
 	AnjutaPreferences *prefs;
 	
 	/* project monitor */
 	guint root_watch_id;
-	 
+	
+	/* ui merge */
+	GtkActionGroup *popup_action_group;
+	GtkActionGroup *menu_action_group;	
+	gint merge_id;
+	
 	/* editor monitor */
+	guint buf_update_timeout_id;
+	gboolean need_symbols_update;
+	GTimer *update_timer;
+	GPtrArray *buffer_update_files;
+	GPtrArray *buffer_update_ids;
 	guint editor_watch_id;
 	gchar *project_root_uri;
 	gchar *project_root_dir;
@@ -79,15 +88,21 @@ struct _SymbolDBPlugin{
 	SymbolDBPrefs *sdbp;
 	
 	GtkWidget *dbv_main;					/* symbol main window [gtk_box] */
-	GtkWidget *dbv_notebook;          		/* main notebook */	
+	GtkWidget *dbv_notebook;          		/* main notebook */
+	GtkWidget *dbv_hbox;					/* hbox for notebook buttons */
 	GtkWidget *scrolled_global; 			/* symbol view scrolledwindow for global
 										   	symbols */
+
+	GtkWidget *local_button;
+	GtkWidget *global_button;
+	GtkWidget *search_button;
+	
 	GtkWidget *scrolled_locals;
 	GtkWidget *scrolled_search;
 	GtkWidget *progress_bar_project;		/* symbol db progress bar - project */
 	GtkWidget *progress_bar_system;			/* symbol db progress bar - system (globals) */
 	
-	GtkWidget *dbv_view_tree;        		/* symbol_db_view */
+	GtkWidget *dbv_view_tree;        		/* symbol_db_view globals */
 	GtkWidget *dbv_view_tab_label;
 	
 	GtkWidget *dbv_view_tree_locals;		/* local symbols */
@@ -112,10 +127,22 @@ struct _SymbolDBPlugin{
 	gint files_count_system_done;
 	gchar *current_scanned_package;
 	GList *session_packages;
+	
+	GTree *proc_id_tree;
+	
+	gboolean is_project_importing;		/* refreshes or resumes after abort */
+	gboolean is_project_updating;		/* makes up to date symbols of the project's files */
+	gboolean is_offline_scanning;		/* detects offline changes to makefile.am */
+	gboolean is_adding_element;			/* we're adding an element */
 };
 
-struct _SymbolDBPluginClass{
+struct _SymbolDBPluginClass {
 	AnjutaPluginClass parent_class;
+	
+	/* signals */
+	void (* project_import_end) 	();
+	void (* globals_import_end) 	();
+	
 };
 
 
