@@ -25,16 +25,15 @@
 #include <sys/wait.h>
 #include <dirent.h>
 #include <string.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtkliststore.h>
+#include <gtk/gtk.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/anjuta-launcher.h>
 #include <libanjuta/interfaces/ianjuta-language.h>
 
 #include "symbol-db-prefs.h"
 
-#define GLADE_FILE PACKAGE_DATA_DIR"/glade/anjuta-symbol-db.glade"
-#define GLADE_ROOT "symbol_prefs"
+#define BUILDER_FILE PACKAGE_DATA_DIR"/glade/anjuta-symbol-db.ui"
+#define BUILDER_ROOT "symbol_prefs"
 #define ICON_FILE "anjuta-symbol-db-plugin-48.png"
 
 
@@ -56,7 +55,7 @@ static unsigned int signals[LAST_SIGNAL] = { 0 };
 
 struct _SymbolDBPrefsPriv {
 	GtkListStore *prefs_list_store;
-	GladeXML *prefs_gxml;
+	GtkBuilder *prefs_bxml;
 	AnjutaLauncher *pkg_config_launcher;	
 	AnjutaPreferences *prefs;
 	
@@ -107,7 +106,7 @@ on_prefs_executable_changed (/*GtkFileChooser *chooser,*/ GtkComboBox *chooser,
 	if (new_file != NULL) 
 	{
 		GtkWidget *fchooser;
-		fchooser = 	glade_xml_get_widget (priv->prefs_gxml, CTAGS_PREFS_KEY);	
+		fchooser = 	GTK_WIDGET (gtk_builder_get_object (priv->prefs_bxml, CTAGS_PREFS));	
 		/*gtk_widget_set_sensitive (fchooser, TRUE);*/
 		
 		anjuta_preferences_set (priv->prefs, CTAGS_PREFS_KEY,
@@ -120,16 +119,10 @@ on_prefs_executable_changed (/*GtkFileChooser *chooser,*/ GtkComboBox *chooser,
 }
 
 static void
-on_gconf_notify_prefs (GConfClient *gclient, guint cnxn_id,
-					   GConfEntry *entry, gpointer user_data)
+on_notify_prefs (AnjutaPreferences* prefs, const gchar* key,
+                 const gchar* value, gpointer user_data)
 {
-	DEBUG_PRINT ("on_gconf_notify_prefs ()");
-}
-
-static gint 
-pkg_list_compare (gconstpointer a, gconstpointer b)
-{
-	return strcmp ((const gchar*)a, (const gchar*)b);
+	DEBUG_PRINT ("%s", "on_notify_prefs ()");
 }
 
 static void
@@ -192,12 +185,12 @@ on_listall_exit (AnjutaLauncher * launcher, int child_pid,
 	priv = sdbp->priv;
 	store = priv->prefs_list_store;
 	
-	DEBUG_PRINT ("on_listall_exit ()");
+	DEBUG_PRINT ("%s", "on_listall_exit ()");
 
 	g_signal_handlers_disconnect_by_func (launcher, on_listall_exit,
 										  user_data);	
 
-	treeview = glade_xml_get_widget (priv->prefs_gxml, "tags_treeview");
+	treeview = GTK_WIDGET (gtk_builder_get_object (priv->prefs_bxml, "tags_treeview"));
 	gtk_widget_set_sensitive (treeview, TRUE);
 	
 	/* we should have pkg_list filled with packages names 
@@ -214,7 +207,7 @@ on_listall_exit (AnjutaLauncher * launcher, int child_pid,
 		return;
 	}
 
-	priv->pkg_list = g_list_sort (priv->pkg_list, pkg_list_compare);
+	priv->pkg_list = g_list_sort (priv->pkg_list, symbol_db_glist_compare_func);
 	item = priv->pkg_list;
 	
 	while (item != NULL)
@@ -260,9 +253,9 @@ on_tag_load_toggled_parseable_cb (SymbolDBSystem *sdbs,
 	priv = sdbp->priv;
 	
 	DEBUG_PRINT ("on_tag_load_toggled_parseable_cb %d", is_parseable);
-	prefs_window = GTK_WINDOW (glade_xml_get_widget (priv->prefs_gxml, "symbol_db_pref_window"));
-	treeview = glade_xml_get_widget (priv->prefs_gxml, "tags_treeview");
-	prefs_progressbar = glade_xml_get_widget (priv->prefs_gxml, "prefs_progressbar");
+	prefs_window = GTK_WINDOW (gtk_builder_get_object (priv->prefs_bxml, "symbol_db_pref_window"));
+	treeview = GTK_WIDGET (gtk_builder_get_object (priv->prefs_bxml, "tags_treeview"));
+	prefs_progressbar = GTK_WIDGET (gtk_builder_get_object (priv->prefs_bxml, "prefs_progressbar"));
 
 	store = priv->prefs_list_store;
 	path = gtk_tree_path_new_from_string (path_str);
@@ -329,7 +322,7 @@ on_tag_load_toggled (GtkCellRendererToggle *cell, char *path_str,
 	
 	priv = sdbp->priv;
 	
-	DEBUG_PRINT ("on_tag_load_toggled ()");
+	DEBUG_PRINT ("%s", "on_tag_load_toggled ()");
 	
 	store = priv->prefs_list_store;
 	path = gtk_tree_path_new_from_string (path_str);
@@ -339,13 +332,13 @@ on_tag_load_toggled (GtkCellRendererToggle *cell, char *path_str,
 						-1);
 	gtk_tree_path_free (path);
 	
-	prefs_progressbar = glade_xml_get_widget (priv->prefs_gxml, "prefs_progressbar");
+	prefs_progressbar = GTK_WIDGET (gtk_builder_get_object (priv->prefs_bxml, "prefs_progressbar"));
 	gtk_widget_show_all (prefs_progressbar);	
 	
 	gtk_progress_bar_set_pulse_step (GTK_PROGRESS_BAR (prefs_progressbar), 1.0);
 	gtk_progress_bar_pulse (GTK_PROGRESS_BAR (prefs_progressbar));
 	
-	treeview = glade_xml_get_widget (priv->prefs_gxml, "tags_treeview");
+	treeview = GTK_WIDGET (gtk_builder_get_object (priv->prefs_bxml, "tags_treeview"));
 	gtk_widget_set_sensitive (treeview, FALSE);
 	
 	pdata = g_new0 (ParseableData, 1);
@@ -357,74 +350,24 @@ on_tag_load_toggled (GtkCellRendererToggle *cell, char *path_str,
 										   pdata);
 }
 
-static void
-on_autoscan_button_toggled (GtkToggleButton *togglebutton, SymbolDBPrefs *sdbp)
-{
-	SymbolDBPrefsPriv *priv;	
-	gboolean check_button_value;
-	priv = sdbp->priv;
-	GtkWidget *check_button;
-	
-	check_button = glade_xml_get_widget (priv->prefs_gxml, PROJECT_AUTOSCAN);
-
-	check_button_value =  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_button));
-	DEBUG_PRINT ("on_check_button_toggled ()");
-	anjuta_preferences_set_int (priv->prefs, PROJECT_AUTOSCAN, check_button_value);
-
-}
-
-static void
-on_update_button_toggled (GtkToggleButton *togglebutton, SymbolDBPrefs *sdbp)
-{
-	SymbolDBPrefsPriv *priv;	
-	gboolean update_button_value;
-	priv = sdbp->priv;
-	GtkWidget *update_button;
-	
-	update_button = glade_xml_get_widget (priv->prefs_gxml, BUFFER_AUTOSCAN);
-
-	update_button_value =  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (update_button));
-	DEBUG_PRINT ("on_update_button_toggled ()");
-	anjuta_preferences_set_int (priv->prefs, BUFFER_AUTOSCAN, update_button_value);	
-
-	g_signal_emit (sdbp, signals[BUFFER_UPDATE_TOGGLED], 0, update_button_value);
-}
-
-static void
-on_parallel_button_toggled (GtkToggleButton *togglebutton, SymbolDBPrefs *sdbp)
-{
-	SymbolDBPrefsPriv *priv;	
-	gboolean parallel_button_value;
-	priv = sdbp->priv;
-	GtkWidget *parallel_button;
-	
-	parallel_button = glade_xml_get_widget (priv->prefs_gxml, PARALLEL_SCAN);
-
-	parallel_button_value =  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (parallel_button));
-	DEBUG_PRINT ("on_parallel_button_toggled ()");
-	anjuta_preferences_set_int (priv->prefs, PARALLEL_SCAN, parallel_button_value);	
-}
-
 static void
 sdb_prefs_init1 (SymbolDBPrefs *sdbp)
 {
 	SymbolDBPrefsPriv *priv;
 	GtkWidget *fchooser;
-	GtkWidget *check_button, *update_button, *parallel_button;
-	gboolean check_button_value, update_button_value, parallel_button_value;
 	gchar *ctags_value;
 
 	priv = sdbp->priv;
 
-	fchooser = 	glade_xml_get_widget (priv->prefs_gxml, CTAGS_PREFS_KEY);
+	fchooser = 	GTK_WIDGET (gtk_builder_get_object (priv->prefs_bxml, CTAGS_PREFS));
 	/* we will reactivate it after the listall has been finished */
 	/*gtk_widget_set_sensitive (fchooser, FALSE);*/
 			
-	anjuta_preferences_add_page (priv->prefs, 
-								 priv->prefs_gxml, 
-								 GLADE_ROOT, 
-								 _("Symbol Database"),  
-								 ICON_FILE);
+	anjuta_preferences_add_from_builder (priv->prefs, 
+									 priv->prefs_bxml, 
+									 BUILDER_ROOT, 
+									 _("Symbol Database"),  
+									 ICON_FILE);
 	
 	ctags_value = anjuta_preferences_get (priv->prefs, CTAGS_PREFS_KEY);
 	
@@ -454,29 +397,10 @@ sdb_prefs_init1 (SymbolDBPrefs *sdbp)
 					  G_CALLBACK (on_prefs_executable_changed), sdbp);	
 	
 
-	priv->prefs_notify_id = anjuta_preferences_notify_add (priv->prefs, 
-												CTAGS_PREFS_KEY, 
-											   on_gconf_notify_prefs, 
-											   priv->prefs, NULL);		
-
-	
-	check_button = glade_xml_get_widget (priv->prefs_gxml, PROJECT_AUTOSCAN);
-	g_signal_connect (G_OBJECT (check_button), "toggled", 
-					  G_CALLBACK (on_autoscan_button_toggled), sdbp);
-	check_button_value = anjuta_preferences_get_int (priv->prefs, PROJECT_AUTOSCAN);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_button), check_button_value);
-
-	update_button = glade_xml_get_widget (priv->prefs_gxml, BUFFER_AUTOSCAN);
-	g_signal_connect (G_OBJECT (update_button), "toggled", 
-					  G_CALLBACK (on_update_button_toggled), sdbp);
-	update_button_value = anjuta_preferences_get_int (priv->prefs, BUFFER_AUTOSCAN);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (update_button), update_button_value);
-	
-	parallel_button	= glade_xml_get_widget (priv->prefs_gxml, PARALLEL_SCAN);
-	g_signal_connect (G_OBJECT (parallel_button), "toggled", 
-					  G_CALLBACK (on_parallel_button_toggled), sdbp);
-	parallel_button_value = anjuta_preferences_get_int (priv->prefs, PARALLEL_SCAN);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (parallel_button), parallel_button_value);
+	priv->prefs_notify_id = anjuta_preferences_notify_add_string (priv->prefs, 
+	                                                              CTAGS_PREFS_KEY, 
+	                                                              on_notify_prefs, 
+	                                                              priv->prefs, NULL);
 	
 	g_free (ctags_value);
 }
@@ -498,12 +422,18 @@ sdb_prefs_init (SymbolDBPrefs *object)
 	
 	priv->pkg_list = NULL;
 	
-	DEBUG_PRINT ("symbol_db_prefs_init ()");
+	DEBUG_PRINT ("%s", "symbol_db_prefs_init ()");
 	
-	if (priv->prefs_gxml == NULL)
+	if (priv->prefs_bxml == NULL)
 	{
+		GError* error = NULL;
 		/* Create the preferences page */
-		priv->prefs_gxml = glade_xml_new (GLADE_FILE, GLADE_ROOT, NULL);	
+		priv->prefs_bxml = gtk_builder_new ();
+		if (!gtk_builder_add_from_file (priv->prefs_bxml, BUILDER_FILE, &error))
+		{
+			g_warning ("Couldn't load builder file: %s", error->message);
+			g_error_free(error);
+		}		
 	}		
 
 	/* init GtkListStore */
@@ -514,7 +444,7 @@ sdb_prefs_init (SymbolDBPrefs *object)
 		require_scan = TRUE;
 	}
 	
-	treeview = glade_xml_get_widget (priv->prefs_gxml, "tags_treeview");
+	treeview = GTK_WIDGET (gtk_builder_get_object (priv->prefs_bxml, "tags_treeview"));
 	/* on_listall_exit will reactivate this */
 	gtk_widget_set_sensitive (treeview, FALSE);
 	gtk_tree_view_set_model (GTK_TREE_VIEW (treeview),
@@ -543,10 +473,10 @@ sdb_prefs_init (SymbolDBPrefs *object)
 	
 	/* frame3 show all */
 	GtkWidget *frame3;
-	frame3 = glade_xml_get_widget (priv->prefs_gxml, "frame3");
+	frame3 = GTK_WIDGET (gtk_builder_get_object (priv->prefs_bxml, "frame3"));
 	gtk_widget_show_all (frame3);
-	GtkWidget *prefs_progressbar = glade_xml_get_widget (priv->prefs_gxml, 
-														 "prefs_progressbar");
+	GtkWidget *prefs_progressbar = GTK_WIDGET (gtk_builder_get_object (priv->prefs_bxml, 
+														 "prefs_progressbar"));
 	gtk_widget_hide (prefs_progressbar);	
 	
 	/* listall launcher thing */
@@ -580,7 +510,7 @@ sdb_prefs_finalize (GObject *object)
 	sdbp = SYMBOL_DB_PREFS (object);
 	priv = sdbp->priv;
 	
-	DEBUG_PRINT ("symbol_db_prefs_finalize ()");
+	DEBUG_PRINT ("%s", "symbol_db_prefs_finalize ()");
 	
 	anjuta_preferences_notify_remove(priv->prefs, priv->prefs_notify_id);
 	anjuta_preferences_remove_page(priv->prefs, _("Symbol Database"));
@@ -594,8 +524,8 @@ sdb_prefs_finalize (GObject *object)
 	g_list_free (priv->pkg_list);
 	priv->pkg_list = NULL;
 
-	if (priv->prefs_gxml != NULL)
-		g_object_unref (priv->prefs_gxml);
+	if (priv->prefs_bxml != NULL)
+		g_object_unref (priv->prefs_bxml);
 
 	if (priv->prefs_list_store != NULL)
 		g_object_unref (priv->prefs_list_store);
@@ -672,7 +602,7 @@ symbol_db_prefs_new (SymbolDBSystem *sdbs, SymbolDBEngine *sdbe_project,
 	while (item != NULL)
 	{
 		g_hash_table_insert (priv->enabled_packages_hash, (gpointer)g_strdup (item->data), 
-							 (gpointer)TRUE);
+							 GINT_TO_POINTER (TRUE));
 		item = item->next;
 	}	
 	
