@@ -28,11 +28,12 @@
 #include <libanjuta/interfaces/ianjuta-terminal.h>
 #include <libanjuta/interfaces/ianjuta-preferences.h>
 #include <libanjuta/interfaces/ianjuta-project-manager.h>
-
+#include <sys/types.h>
+#include <unistd.h>
 #include <signal.h>
 
-#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-terminal-plugin.ui"
-#define PREFS_GLADE PACKAGE_DATA_DIR"/glade/anjuta-terminal-plugin.glade"
+#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-terminal-plugin.xml"
+#define PREFS_BUILDER PACKAGE_DATA_DIR"/glade/anjuta-terminal-plugin.ui"
 #define ICON_FILE "anjuta-terminal-plugin-48.png"
 
 /* Some desktop/gnome-terminal gconf keys. */
@@ -145,7 +146,7 @@ terminal_set_preferences (VteTerminal *term, AnjutaPreferences *pref)
 	g_return_if_fail (client != NULL);
 	
 	/* Update the currently available list of terminal profiles */
-	setting = anjuta_preferences_get_int (pref,
+	setting = anjuta_preferences_get_bool (pref,
 										  PREFS_TERMINAL_PROFILE_USE_DEFAULT);
 	if (setting)
 	{
@@ -177,7 +178,8 @@ terminal_set_preferences (VteTerminal *term, AnjutaPreferences *pref)
 	g_free (text);
 	
 	setting = GET_PROFILE_BOOL (GCONF_CURSOR_BLINK);
-	vte_terminal_set_cursor_blinks ((term), setting);
+	vte_terminal_set_cursor_blink_mode ((term), 
+	                                    setting ? VTE_CURSOR_BLINK_ON : VTE_CURSOR_BLINK_OFF);
 	setting = GET_PROFILE_BOOL (GCONF_SILENT_BELL);
 	vte_terminal_set_audible_bell (term, !setting);
 	value = GET_PROFILE_INT (GCONF_SCROLLBACK_LINES);
@@ -256,15 +258,27 @@ preferences_changed (AnjutaPreferences *prefs, TerminalPlugin *term)
 }
 
 static void
-on_gconf_notify_prefs (GConfClient *gclient, guint cnxn_id,
-					   GConfEntry *entry, gpointer user_data)
+on_notify_prefs_profile(AnjutaPreferences* prefs,
+                        const gchar* key,
+                        const gchar* value,
+                        gpointer user_data)
 {
 	TerminalPlugin *tp = ANJUTA_PLUGIN_TERMINAL (user_data);
 	preferences_changed (tp->prefs, tp);
 }
 
-#define REGISTER_NOTIFY(key, func) \
-	notify_id = anjuta_preferences_notify_add (tp->prefs, \
+static void
+on_notify_prefs_default (AnjutaPreferences* prefs,
+                         const gchar* key,
+                         gboolean value,
+                         gpointer user_data)
+{
+	TerminalPlugin *tp = ANJUTA_PLUGIN_TERMINAL (user_data);
+	preferences_changed (tp->prefs, tp);
+}
+
+#define REGISTER_NOTIFY(key, func, type) \
+	notify_id = anjuta_preferences_notify_add_##type (tp->prefs, \
 											   key, func, tp, NULL); \
 	tp->gconf_notify_ids = g_list_prepend (tp->gconf_notify_ids, \
 										   GUINT_TO_POINTER (notify_id));
@@ -272,8 +286,8 @@ static void
 prefs_init (TerminalPlugin *tp)
 {
 	guint notify_id;
-	REGISTER_NOTIFY (PREFS_TERMINAL_PROFILE, on_gconf_notify_prefs);
-	REGISTER_NOTIFY (PREFS_TERMINAL_PROFILE_USE_DEFAULT, on_gconf_notify_prefs);
+	REGISTER_NOTIFY (PREFS_TERMINAL_PROFILE, on_notify_prefs_profile, string);
+	REGISTER_NOTIFY (PREFS_TERMINAL_PROFILE_USE_DEFAULT, on_notify_prefs_default, bool);
 }
 
 static void
@@ -853,17 +867,26 @@ on_concat_string (gpointer data, gpointer user_data)
 static void
 ipreferences_merge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError** e)
 {
+	GError* error = NULL;
 	GSList *profiles;
 	GConfClient *client;	
 	
 	/* Create the terminal preferences page */
 	TerminalPlugin* term_plugin = ANJUTA_PLUGIN_TERMINAL (ipref);
-	GladeXML *gxml = glade_xml_new (PREFS_GLADE, "preferences_dialog_terminal", NULL);
-	anjuta_preferences_add_page (term_plugin->prefs, gxml,
+	GtkBuilder *bxml = gtk_builder_new ();
+
+	if (!gtk_builder_add_from_file (bxml, PREFS_BUILDER, &error))
+	{
+		g_warning ("Couldn't load builder file: %s", error->message);
+		g_error_free (error);
+	}
+
+
+	anjuta_preferences_add_from_builder (term_plugin->prefs, bxml,
 									"Terminal", _("Terminal"), ICON_FILE);
 	
-	term_plugin->pref_profile_combo = glade_xml_get_widget (gxml, "profile_list_combo");
-	term_plugin->pref_default_button = glade_xml_get_widget (gxml, "preferences_toggle:bool:1:0:terminal.default.profile");
+	term_plugin->pref_profile_combo = GTK_WIDGET (gtk_builder_get_object (bxml, "profile_list_combo"));
+	term_plugin->pref_default_button = GTK_WIDGET (gtk_builder_get_object (bxml, "preferences_toggle:bool:1:0:terminal.default.profile"));
 
 	/* Update the currently available list of terminal profiles */
 	client = gconf_client_get_default ();
@@ -904,7 +927,7 @@ ipreferences_merge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError**
 		gtk_widget_set_sensitive (term_plugin->pref_default_button, FALSE);
 	}
 	
-	g_object_unref (gxml);
+	g_object_unref (bxml);
 }
 
 static void
