@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 /*
@@ -25,7 +25,8 @@
  *---------------------------------------------------------------------------*/
 
 #include <config.h>
-
+#include <errno.h>
+#include <sys/stat.h>
 #include "editor.h"
 
 #include "dialog.h"
@@ -36,11 +37,12 @@
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
 #include <libanjuta/interfaces/ianjuta-editor.h>
 #include <libanjuta/interfaces/ianjuta-file-loader.h>
-
-#include <libgnomeui/libgnomeui.h>
-
+#include <glib.h>
+#include <gdk/gdk.h>
 #include <gtk/gtk.h>
-
+#include <sys/types.h>
+#include <fcntl.h>
+#include <unistd.h>
 #include <string.h>
 
 /*---------------------------------------------------------------------------*/
@@ -90,7 +92,7 @@ struct _ATPToolEditor
 	ATPVariableDialog input_file_var;
 	ATPVariableDialog input_string_var;
 	GtkToggleButton *shortcut_bt;
-	GnomeIconEntry *icon_en;
+	GtkButton *icon_en;
 	gchar* shortcut;
 	ATPUserTool *tool;
 	ATPToolDialog* parent;
@@ -119,20 +121,22 @@ struct _ATPToolEditor
 #define TOOL_INPUT_VARIABLE "input_button"
 #define TOOL_SHORTCUT "shortcut_bt"
 #define TOOL_ICON "icon_entry"
-
-#define EDITOR_RESPONSE_SIGNAL "on_editor_dialog_response"
-#define EDITOR_PARAM_VARIABLE_SIGNAL "on_variable_parameter"
-#define EDITOR_DIR_VARIABLE_SIGNAL "on_variable_directory"
-#define EDITOR_INPUT_VARIABLE_SIGNAL "on_variable_input"
-#define EDITOR_INPUT_CHANGED_SIGNAL "on_input_changed"
-#define EDITOR_TOGGLE_TERMINAL_SIGNAL "on_toggle_terminal"
-#define EDITOR_TOGGLE_SHORCUT_SIGNAL "on_toggle_shorcut"
-#define EDITOR_TOGGLE_SCRIPT_SIGNAL "on_toggle_script"
-
+#define TOOL_BROWSE_WORKING_DIR "browse_button_directory_entry"
+#define TOOL_BROWSE_COMMAND "browse_button_command_entry"
 #define TOOL_VARIABLE "variable_dialog"
 #define VARIABLE_TREEVIEW "variable_treeview"
-#define VARIABLE_RESPONSE_SIGNAL "on_variable_dialog_response"
-#define VARIABLE_ACTIVATE_SIGNAL "on_variable_activate_row"
+
+void on_variable_activate_row (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, gpointer user_data);
+void on_variable_dialog_response (GtkDialog *dialog, gint response, gpointer user_data);
+void on_editor_icon_entry_clicked (GtkButton *button, gpointer user_data);
+void on_editor_terminal_toggle (GtkToggleButton *tb, gpointer user_data);
+void on_editor_script_toggle (GtkToggleButton *tb, gpointer user_data);
+void on_editor_input_changed (GtkComboBox *combo, gpointer user_data);
+void on_editor_dialog_response (GtkDialog *dialog, gint response, gpointer user_data);
+void on_editor_param_variable_show (GtkButton *button, gpointer user_data);
+void on_editor_dir_variable_show (GtkButton *button, gpointer user_data);
+void on_editor_input_variable_show (GtkButton *button, gpointer user_data);
+void on_editor_shortcut_toggle (GtkToggleButton *tb, gpointer user_data);
 
 /* Add helper function
  *---------------------------------------------------------------------------*/
@@ -386,8 +390,8 @@ get_current_name (GtkTreeView *view)
 	return NULL;
 }
 
-static void
-on_variable_activate (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, gpointer user_data)
+void
+on_variable_activate_row (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, gpointer user_data)
 {
 	ATPVariableDialog *this = (ATPVariableDialog*)user_data;
 	GtkTreeIter iter;
@@ -404,8 +408,8 @@ on_variable_activate (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColum
 	gtk_widget_hide (GTK_WIDGET (this->dialog));
 }
 
-static void
-on_variable_response (GtkDialog *dialog, gint response, gpointer user_data)
+void
+on_variable_dialog_response (GtkDialog *dialog, gint response, gpointer user_data)
 {
 	ATPVariableDialog *this = (ATPVariableDialog *)user_data;
 	gchar* name;
@@ -426,10 +430,11 @@ on_variable_response (GtkDialog *dialog, gint response, gpointer user_data)
 static gboolean
 atp_variable_dialog_show (ATPVariableDialog* this, ATPFlags flag)
 {
-	GladeXML *xml;
+	GtkBuilder *bxml = gtk_builder_new ();
 	GtkTreeModel *model;
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
+	GError* error = NULL;
 
 	if (this->dialog != NULL)
 	{
@@ -437,18 +442,20 @@ atp_variable_dialog_show (ATPVariableDialog* this, ATPFlags flag)
 		if (this->dialog) gtk_window_present (GTK_WINDOW (this->dialog));
 		return TRUE;
 	}
-	
-	if (NULL == (xml = glade_xml_new(GLADE_FILE, TOOL_VARIABLE, NULL)))
+
+	if (!gtk_builder_add_from_file (bxml, GLADE_FILE, &error))
 	{
+		g_warning ("Couldn't load builder file: %s", error->message);
+		g_error_free (error);
 		anjuta_util_dialog_error (GTK_WINDOW (this->editor->dialog), _("Unable to build user interface for tool variable"));
 		return FALSE;
 	}
-	this->dialog = GTK_DIALOG (glade_xml_get_widget(xml, TOOL_VARIABLE));
+	this->dialog = GTK_DIALOG (gtk_builder_get_object (bxml, TOOL_VARIABLE));
 	gtk_widget_show (GTK_WIDGET (this->dialog));
 	gtk_window_set_transient_for (GTK_WINDOW (this->dialog), GTK_WINDOW (this->editor->dialog));
 
 	/* Create variable list */
-	this->view = GTK_TREE_VIEW (glade_xml_get_widget(xml, VARIABLE_TREEVIEW));
+	this->view = GTK_TREE_VIEW (gtk_builder_get_object (bxml, VARIABLE_TREEVIEW));
 	model = GTK_TREE_MODEL (gtk_list_store_new (ATP_N_VARIABLE_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING));
 	gtk_tree_view_set_model (this->view, model);
 
@@ -464,12 +471,11 @@ atp_variable_dialog_show (ATPVariableDialog* this, ATPFlags flag)
 	g_object_unref (model);
 	atp_variable_dialog_populate (this, flag);
 
-	/* Connect all signals */	
-	glade_xml_signal_connect_data (xml, VARIABLE_RESPONSE_SIGNAL, GTK_SIGNAL_FUNC (on_variable_response), this);
-	glade_xml_signal_connect_data (xml, VARIABLE_ACTIVATE_SIGNAL, GTK_SIGNAL_FUNC (on_variable_activate), this);
+	/* Connect all signals */
+	gtk_builder_connect_signals (bxml, this);
 	g_signal_connect (G_OBJECT (this->dialog), "delete_event", G_CALLBACK (gtk_widget_hide_on_delete), NULL);
 
-	g_object_unref (xml);
+	g_object_unref (bxml);
 
 	return TRUE;
 }
@@ -477,6 +483,31 @@ atp_variable_dialog_show (ATPVariableDialog* this, ATPFlags flag)
 /* Tool editor dialog
  *---------------------------------------------------------------------------*/
 
+void
+on_editor_icon_entry_clicked (GtkButton *button, gpointer user_data)
+{
+	ATPToolEditor *this = (ATPToolEditor *)user_data;
+	GtkWidget *dialog;
+	dialog = gtk_file_chooser_dialog_new ("Open File",
+								NULL,
+								GTK_FILE_CHOOSER_ACTION_OPEN,
+								GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+								GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+								NULL);
+	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
+	{
+		char *filename;
+		GtkWidget* image;
+
+		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+		image = gtk_image_new_from_file (filename);
+		gtk_button_set_image (button, image);
+		atp_user_tool_set_icon (this->tool, filename);
+		g_free (filename);
+	}
+	gtk_widget_destroy (dialog);
+}
+
 static void
 atp_clear_tool_editor(ATPToolEditor* this)
 {
@@ -605,10 +636,15 @@ atp_populate_tool_editor(ATPToolEditor* this)
 	}
 	atp_editor_update_shortcut (this);
 
-	gnome_icon_entry_set_filename (this->icon_en, atp_user_tool_get_icon (this->tool));
+	if (atp_user_tool_get_icon (this->tool))
+	{
+		GtkWidget* image;
+		image = gtk_image_new_from_file (atp_user_tool_get_icon (this->tool));
+		gtk_button_set_image (this->icon_en, image);
+	}
 }
 
-static void
+void
 on_editor_terminal_toggle (GtkToggleButton *tb, gpointer user_data)
 {
 	ATPToolEditor *this = (ATPToolEditor *)user_data;
@@ -616,7 +652,7 @@ on_editor_terminal_toggle (GtkToggleButton *tb, gpointer user_data)
 	atp_update_sensitivity (this);
 }
 
-static void
+void
 on_editor_script_toggle (GtkToggleButton *tb, gpointer user_data)
 {
 	ATPToolEditor *this = (ATPToolEditor *)user_data;
@@ -641,9 +677,8 @@ on_editor_script_toggle (GtkToggleButton *tb, gpointer user_data)
 			}
 			name = atp_remove_mnemonic (command);
 			g_free (command);
-			command = g_build_filename (g_get_home_dir(),
-										LOCAL_ANJUTA_SCRIPT_DIRECTORY,
-										name, NULL);
+
+			command = anjuta_util_get_user_data_file_path ("scripts/", name, NULL);
 			g_free (name);
 
 			/* Find a new file name */
@@ -666,7 +701,7 @@ on_editor_script_toggle (GtkToggleButton *tb, gpointer user_data)
 	}
 }
 
-static void
+void
 on_editor_input_changed (GtkComboBox *combo, gpointer user_data)
 {
 	ATPToolEditor *this = (ATPToolEditor *)user_data;
@@ -674,14 +709,13 @@ on_editor_input_changed (GtkComboBox *combo, gpointer user_data)
 	atp_update_sensitivity (this);
 }
 
-static void
-on_editor_response (GtkDialog *dialog, gint response, gpointer user_data)
+void
+on_editor_dialog_response (GtkDialog *dialog, gint response, gpointer user_data)
 {
 	ATPToolEditor* this = (ATPToolEditor*)user_data;
 	gchar* name;
 	gchar* data;
 	ATPInputType in_type;
-	gchar* value;
 	guint accel_key;
 	GdkModifierType accel_mods;
 	GtkAccelGroup* group;
@@ -727,7 +761,7 @@ on_editor_response (GtkDialog *dialog, gint response, gpointer user_data)
 			group = anjuta_ui_get_accel_group(ui);
 			if (gtk_accel_group_query (group, accel_key, accel_mods, NULL) != NULL)
 			{
-				if (!anjuta_util_dialog_boolean_question (GTK_WINDOW (this->dialog), _("The shortcut is already used by another component in Anjuta. Do you want to keep it anyway ?")))
+				if (!anjuta_util_dialog_boolean_question (GTK_WINDOW (this->dialog), _("The shortcut is already used by another component in Anjuta. Do you want to keep it anyway?")))
 				{
 					return;
 				}
@@ -771,18 +805,17 @@ on_editor_response (GtkDialog *dialog, gint response, gpointer user_data)
 
 		atp_user_tool_set_accelerator (this->tool, accel_key, accel_mods);
 
-		value = gnome_icon_entry_get_filename (this->icon_en);	
-		atp_user_tool_set_icon (this->tool, value);
-		g_free (value);	
-
 		/* Open script in editor if requested */
 		if (gtk_toggle_button_get_active (this->script_tb))
 		{
 			IAnjutaDocumentManager *docman;
-			IAnjutaEditor *editor;
+			IAnjutaDocument *doc;
+			GFile* file;
 
 			/* Check that default script directory exist */
-			data = g_build_filename (g_get_home_dir(), LOCAL_ANJUTA_SCRIPT_DIRECTORY, NULL);
+			data = anjuta_util_get_user_data_file_path ("scripts/", NULL);
+
+			// TODO: Replace with g_mkdir_with_parents
 			make_directory (data);
 			g_free (data);
 
@@ -816,24 +849,25 @@ on_editor_response (GtkDialog *dialog, gint response, gpointer user_data)
 				return;
 			}
 
-			editor = ianjuta_document_manager_find_editor_with_path (docman, data, NULL);
-			if (editor == NULL)
+			file = g_file_new_for_path (data);
+			g_free (data);
+			doc =
+				ianjuta_document_manager_find_document_with_file 
+							   (docman, file, NULL);
+			if (doc == NULL)
 			{
 				IAnjutaFileLoader* loader;
-				gchar *uri;
 
 				/* Not found, load file */
 				loader = IANJUTA_FILE_LOADER (anjuta_shell_get_interface (ANJUTA_PLUGIN (this->parent->plugin)->shell, IAnjutaFileLoader, NULL));
-				uri = g_strdup_printf("file:///%s", data);
-				ianjuta_file_loader_load (loader, uri, FALSE, NULL);
-				g_free (uri);
+				ianjuta_file_loader_load (loader, file, FALSE, NULL);
 			}
 			else
 			{
 				/* Set as current */
-				ianjuta_document_manager_set_current_editor (docman, editor, NULL);
+				ianjuta_document_manager_set_current_document (docman, doc, NULL);
 			}
-			g_free (data);
+			g_object_unref (file);
 		}
 	}
 	
@@ -842,7 +876,7 @@ on_editor_response (GtkDialog *dialog, gint response, gpointer user_data)
 	atp_tool_editor_free (this);
 }
 
-static void
+void
 on_editor_param_variable_show (GtkButton *button, gpointer user_data)
 {
 	ATPToolEditor* this = (ATPToolEditor*)user_data;
@@ -850,7 +884,7 @@ on_editor_param_variable_show (GtkButton *button, gpointer user_data)
 	atp_variable_dialog_show (&this->param_var, ATP_DEFAULT_VARIABLE);	
 }
 
-static void
+void
 on_editor_dir_variable_show (GtkButton *button, gpointer user_data)
 {
 	ATPToolEditor* this = (ATPToolEditor*)user_data;
@@ -858,7 +892,7 @@ on_editor_dir_variable_show (GtkButton *button, gpointer user_data)
 	atp_variable_dialog_show (&this->dir_var, ATP_DIRECTORY_VARIABLE);
 }
 
-static void
+void
 on_editor_input_variable_show (GtkButton *button, gpointer user_data)
 {
 	ATPToolEditor* this = (ATPToolEditor*)user_data;
@@ -937,7 +971,7 @@ on_editor_get_keys(GtkWidget *widget, GdkEventKey *event, gpointer user_data)
 	return TRUE;
 }
 
-static void
+void
 on_editor_shortcut_toggle (GtkToggleButton *tb, gpointer user_data)
 {
 	ATPToolEditor *this = (ATPToolEditor *)user_data;
@@ -958,10 +992,56 @@ on_editor_shortcut_toggle (GtkToggleButton *tb, gpointer user_data)
 	}
 }
 
+static void
+on_editor_browse_button_clicked (GtkButton *button, GtkEntry *entry)
+{
+	GtkWidget *dialog;
+	dialog = gtk_file_chooser_dialog_new ("Open File",
+					      NULL,
+					      GTK_FILE_CHOOSER_ACTION_OPEN,
+					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					      GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+					      NULL);
+	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
+	{
+		char *filename;
+		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+
+		gtk_entry_set_text (entry, filename);
+
+		g_free (filename);
+	}
+	gtk_widget_destroy(dialog);
+}
+
+static void
+on_editor_browse_button_dir_clicked (GtkButton *button, GtkEntry *entry)
+{
+	GtkWidget *dialog;
+	dialog = gtk_file_chooser_dialog_new ("Open",
+					      NULL,
+					      GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
+					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					      GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+					      NULL);
+	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
+	{
+		char *filename;
+		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+
+		gtk_entry_set_text (entry, filename);
+
+		g_free (filename);
+	}
+	gtk_widget_destroy(dialog);
+}
+
 gboolean
 atp_tool_editor_show (ATPToolEditor* this)
 {
-	GladeXML *xml;
+	GtkWidget *button;
+	GtkBuilder *bxml = gtk_builder_new ();
+	GError* error = NULL;
 
 	if (this->dialog != NULL)
 	{
@@ -970,36 +1050,44 @@ atp_tool_editor_show (ATPToolEditor* this)
 		return TRUE;
 	}
 
-	if (NULL == (xml = glade_xml_new(GLADE_FILE, TOOL_EDITOR, NULL)))
+	if (!gtk_builder_add_from_file (bxml, GLADE_FILE, &error))
 	{
+		g_warning ("Couldn't load builder file: %s", error->message);
 		anjuta_util_dialog_error (atp_tool_dialog_get_window (this->parent), _("Unable to build user interface for tool editor"));
 		g_free(this);
-
+		g_error_free (error);
 		return FALSE;
 	}
-	this->dialog = glade_xml_get_widget(xml, TOOL_EDITOR);
+	this->dialog = GTK_WIDGET (gtk_builder_get_object (bxml, TOOL_EDITOR));
 	gtk_widget_show (this->dialog);
 	gtk_window_set_transient_for (GTK_WINDOW (this->dialog), atp_plugin_get_app_window (this->parent->plugin));
 
-	this->name_en = GTK_EDITABLE (glade_xml_get_widget (xml, TOOL_NAME));
-	this->command_en = GTK_EDITABLE (glade_xml_get_widget (xml, TOOL_COMMAND));
-	this->param_en = GTK_EDITABLE (glade_xml_get_widget (xml, TOOL_PARAM));
+	this->name_en = GTK_EDITABLE (gtk_builder_get_object (bxml, TOOL_NAME));
+	this->command_en = GTK_EDITABLE (gtk_builder_get_object (bxml, TOOL_COMMAND));
+	this->param_en = GTK_EDITABLE (gtk_builder_get_object (bxml, TOOL_PARAM));
 	atp_variable_dialog_set_entry (&this->param_var, this->param_en);
-	this->dir_en = GTK_EDITABLE (glade_xml_get_widget (xml, TOOL_WORKING_DIR));
+	this->dir_en = GTK_EDITABLE (gtk_builder_get_object (bxml, TOOL_WORKING_DIR));
 	atp_variable_dialog_set_entry (&this->dir_var, this->dir_en);
-	this->enabled_tb = GTK_TOGGLE_BUTTON (glade_xml_get_widget (xml, TOOL_ENABLED));
-	this->terminal_tb = GTK_TOGGLE_BUTTON (glade_xml_get_widget(xml, TOOL_TERMINAL));
-	this->autosave_tb = GTK_TOGGLE_BUTTON (glade_xml_get_widget(xml, TOOL_AUTOSAVE));
-	this->script_tb = GTK_TOGGLE_BUTTON (glade_xml_get_widget(xml, TOOL_SCRIPT));
-	this->output_com = GTK_COMBO_BOX (glade_xml_get_widget(xml, TOOL_OUTPUT));
-	this->error_com = GTK_COMBO_BOX (glade_xml_get_widget(xml, TOOL_ERROR));
-	this->input_com = GTK_COMBO_BOX (glade_xml_get_widget(xml, TOOL_INPUT));
-	this->input_en = GTK_EDITABLE (glade_xml_get_widget(xml, TOOL_INPUT_VALUE));
-	this->input_var_bt = GTK_BUTTON (glade_xml_get_widget(xml, TOOL_INPUT_VARIABLE));
-	this->shortcut_bt = GTK_TOGGLE_BUTTON (glade_xml_get_widget(xml, TOOL_SHORTCUT));
+	this->enabled_tb = GTK_TOGGLE_BUTTON (gtk_builder_get_object (bxml, TOOL_ENABLED));
+	this->terminal_tb = GTK_TOGGLE_BUTTON (gtk_builder_get_object (bxml, TOOL_TERMINAL));
+	this->autosave_tb = GTK_TOGGLE_BUTTON (gtk_builder_get_object (bxml, TOOL_AUTOSAVE));
+	this->script_tb = GTK_TOGGLE_BUTTON (gtk_builder_get_object (bxml, TOOL_SCRIPT));
+	this->output_com = GTK_COMBO_BOX (gtk_builder_get_object (bxml, TOOL_OUTPUT));
+	this->error_com = GTK_COMBO_BOX (gtk_builder_get_object (bxml, TOOL_ERROR));
+	this->input_com = GTK_COMBO_BOX (gtk_builder_get_object (bxml, TOOL_INPUT));
+	this->input_en = GTK_EDITABLE (gtk_builder_get_object (bxml, TOOL_INPUT_VALUE));
+	this->input_var_bt = GTK_BUTTON (gtk_builder_get_object (bxml, TOOL_INPUT_VARIABLE));
+	this->shortcut_bt = GTK_TOGGLE_BUTTON (gtk_builder_get_object (bxml, TOOL_SHORTCUT));
 	atp_variable_dialog_set_entry (&this->input_file_var, this->input_en);
 	atp_variable_dialog_set_entry (&this->input_string_var, this->input_en);
-	this->icon_en = GNOME_ICON_ENTRY (glade_xml_get_widget(xml, TOOL_ICON));
+	this->icon_en = GTK_BUTTON (gtk_builder_get_object (bxml, TOOL_ICON));
+
+	button = GTK_WIDGET (gtk_builder_get_object (bxml, TOOL_BROWSE_WORKING_DIR));
+	g_signal_connect(G_OBJECT(button), "clicked", 
+					G_CALLBACK(on_editor_browse_button_dir_clicked), this->dir_en);
+	button = GTK_WIDGET (gtk_builder_get_object (bxml, TOOL_BROWSE_COMMAND));
+	g_signal_connect(G_OBJECT(button), "clicked", 
+					G_CALLBACK(on_editor_browse_button_clicked), this->command_en);
 
 	/* Add combox box value */
 	set_combo_box_enum_model (this->error_com, atp_get_error_type_list());
@@ -1010,17 +1098,10 @@ atp_tool_editor_show (ATPToolEditor* this)
 	atp_populate_tool_editor (this);
 	atp_update_sensitivity (this);
 
-	/* Connect all signals */	
-	glade_xml_signal_connect_data (xml, EDITOR_RESPONSE_SIGNAL, GTK_SIGNAL_FUNC (on_editor_response), this);
-	glade_xml_signal_connect_data (xml, EDITOR_PARAM_VARIABLE_SIGNAL, GTK_SIGNAL_FUNC (on_editor_param_variable_show), this);
-	glade_xml_signal_connect_data (xml, EDITOR_DIR_VARIABLE_SIGNAL, GTK_SIGNAL_FUNC (on_editor_dir_variable_show), this);
-	glade_xml_signal_connect_data (xml, EDITOR_TOGGLE_SHORCUT_SIGNAL, GTK_SIGNAL_FUNC (on_editor_shortcut_toggle), this);
-	glade_xml_signal_connect_data (xml, EDITOR_TOGGLE_TERMINAL_SIGNAL, GTK_SIGNAL_FUNC (on_editor_terminal_toggle), this);
-	glade_xml_signal_connect_data (xml, EDITOR_TOGGLE_SCRIPT_SIGNAL, GTK_SIGNAL_FUNC (on_editor_script_toggle), this);
-	glade_xml_signal_connect_data (xml, EDITOR_INPUT_VARIABLE_SIGNAL, GTK_SIGNAL_FUNC (on_editor_input_variable_show), this);
-	glade_xml_signal_connect_data (xml, EDITOR_INPUT_CHANGED_SIGNAL, GTK_SIGNAL_FUNC (on_editor_input_changed), this);
+	/* Connect all signals */
+	gtk_builder_connect_signals (bxml, this);
 
-	g_object_unref (xml);
+	g_object_unref (bxml);
 
 	return TRUE;
 }
@@ -1072,6 +1153,8 @@ atp_tool_editor_free (ATPToolEditor *this)
 
 	if (this->shortcut != NULL) g_free (this->shortcut);
 
+	if (atp_user_tool_get_name (this->tool) == NULL) atp_user_tool_free(this->tool);
+	
 	if (this->owner == NULL)
 	{
 		/* tool editor is not in a list */
